@@ -7,30 +7,30 @@ basic actions on behalf of the forum application
 import os
 import platform
 
-VERSION = (0, 8, 3)
+VERSION = (0, 10, 3)
+
+default_app_config = 'askbot.apps.AskbotConfig'
 
 #keys are module names used by python imports,
 #values - the package qualifier to use for pip
 REQUIREMENTS = {
     'appconf': 'django-appconf<=1.0.3',
     'akismet': 'akismet==1.0.1',
-    'avatar': 'django-avatar==2.0',
+    'avatar': 'django-avatar==2.2.1',
     'bs4': 'beautifulsoup4<=4.4.1',
     'coffin': 'Coffin>=0.3,<=0.3.8',
     'compressor': 'django-compressor>=1.3,<=1.5',
-    'django': 'django>=1.5,<1.7',
+    'django': 'django>=1.8,<1.9',
     'django_countries': 'django-countries==3.3',
-    'django_transaction_signals': 'django-transaction-signals==1.0.0',
     'djcelery': 'django-celery>=3.0.11,<=3.1.17',
     'celery': 'celery==3.1.18',
     'djkombu': 'django-kombu==0.9.4',
-    'followit': 'django-followit==0.0.10',
+    'followit': 'django-followit==0.2.1',
     'html5lib': 'html5lib==0.9999999',
-    'jinja2': 'Jinja2==2.8',
+    'jinja2': 'Jinja2>=2.8,<3',
     'jsonfield': 'jsonfield<=1.0.3',
     'jwt': 'pyjwt<=1.7.1',
     'keyedcache': 'django-keyedcache<=1.5.1',
-    'longerusername': 'longerusername<=0.4',
     'markupsafe': 'MarkupSafe<=1.1.1',
     'markdown2': 'markdown2<=2.3.1',
     'mock': 'mock==2.0.0',
@@ -39,15 +39,15 @@ REQUIREMENTS = {
     'picklefield': 'django-picklefield==0.3.0',
     'PIL': 'Pillow<=6.2.2',
     'pystache': 'pystache==0.3.1',
-    'pytz': 'pytz<=2016.4',
+    'pytz': 'pytz==2019.3',
     'captcha': 'django-recaptcha>=1.0.3,<=1.0.5',
     'cas': 'python-cas==1.1.0',
     'responses': 'responses>=0.9.0',
     'requirements': 'requirements-parser==0.1.0',
-    'robots': 'django-robots==1.0',
+    'robots': 'django-robots==1.1',
     'regex': 'regex',
     'sanction': 'sanction==0.3.1',
-    'south': 'South>=0.7.1,<=1.0.2',
+    'simplejson': 'simplejson<=3.8.2',
     'six': 'six==1.10.0',
     'threaded_multihost': 'django-threaded-multihost<=1.4-1',
     'tinymce': 'django-tinymce==1.5.3',
