@@ -8,25 +8,25 @@ from askbot.deps import livesettings
 from askbot.conf.super_groups import REP_AND_BADGES
 
 KARMA_AND_BADGE_VISIBILITY = livesettings.ConfigurationGroup(
-                    'KARMA_AND_BADGE_VISIBILITY',
-                    _('Karma & Badge visibility'),
-                    super_group = REP_AND_BADGES
-                )
+    'KARMA_AND_BADGE_VISIBILITY',
+    _('Karma & Badge visibility'),
+    super_group=REP_AND_BADGES
+)
 
 
 settings.register(
     livesettings.StringValue(
         KARMA_AND_BADGE_VISIBILITY,
         'KARMA_MODE',
-        default = 'public',
-        choices = (
+        default='public',
+        choices=(
             ('public', 'show publicly'),
             ('private', 'show to owners only'),
             ('hidden', 'hide completely'),
-        ),#todo: later implement hidden mode
-        description = _("Visibility of karma"),
-        clear_cache = True,
-        help_text = _(
+        ),  # TODO: Later implement hidden mode
+        description=_("Visibility of karma"),
+        clear_cache=True,
+        help_text=_(
             "User's karma may be shown publicly or only to the owners"
         )
     )
@@ -36,15 +36,13 @@ settings.register(
     livesettings.StringValue(
         KARMA_AND_BADGE_VISIBILITY,
         'BADGES_MODE',
-        default = 'public',
-        choices = (
+        default='public',
+        choices=(
             ('public', 'show publicly'),
             ('hidden', 'hide completely')
-        ),#todo: later implement private mode
-        description = _("Visibility of badges"),
-        clear_cache = True,
-        help_text = _(
-            'Badges can be either publicly shown or completely hidden'
-        )
+        ),  # TODO: Later implement private mode
+        description=_("Visibility of badges"),
+        clear_cache=True,
+        help_text=_('Badges can be either publicly shown or completely hidden')
     )
 )
