@@ -1,17 +1,17 @@
 """
 Sidebar settings
 """
+from django.utils.translation import ugettext_lazy as _
 from askbot.conf.settings_wrapper import settings
 from askbot.deps.livesettings import ConfigurationGroup
 from askbot.deps.livesettings import values
-from django.utils.translation import ugettext_lazy as _
 from askbot.conf.super_groups import CONTENT_AND_UI
 
 SIDEBAR_PROFILE = ConfigurationGroup(
-                    'SIDEBAR_PROFILE',
-                    _('User profile sidebar'),
-                    super_group = CONTENT_AND_UI
-                )
+    'SIDEBAR_PROFILE',
+    _('User profile sidebar'),
+    super_group=CONTENT_AND_UI
+)
 
 settings.register(
     values.LongStringValue(
@@ -21,12 +21,10 @@ settings.register(
         default='',
         localized=True,
         help_text=_(
-                    'Use this area to enter content at the TOP of the sidebar'
-                    'in HTML format.   When using this option '
-                    '(as well as the sidebar footer), please '
-                    'use the HTML validation service to make sure that '
-                    'your input is valid and works well in all browsers.'
-        )
+            'Use this area to enter content at the TOP of the sidebar in HTML '
+            'format. When using this option (as well as the sidebar footer), '
+            'please use the HTML validation service to make sure that your '
+            'input is valid and works well in all browsers.')
     )
 )
 
