@@ -2,11 +2,10 @@
 import cgi
 import functools
 import httplib
-import jwt
-import random
 import re
 import urllib
 import urlparse
+from collections import OrderedDict
 from askbot.utils.html import site_url
 from askbot.utils.functions import format_setting_name
 from askbot.utils.loading import load_module, module_exists
@@ -18,8 +17,7 @@ import oauth2 as oauth # OAuth1 protocol
 from django.db.models.query import Q
 from django.conf import settings
 from django.core.urlresolvers import reverse
-from django.utils import simplejson
-from django.utils.datastructures import SortedDict
+import simplejson
 from django.utils.translation import ugettext as _
 from django.core.exceptions import ImproperlyConfigured
 from askbot.deps.django_authopenid import providers
@@ -38,12 +36,16 @@ try:
 except:
     from yadis import xri
 
-import time, base64, hmac, hashlib, operator, logging
+import time, base64, hashlib, operator, logging
 from models import Association, Nonce
 
 __all__ = ['OpenID', 'DjangoOpenIDStore', 'from_openid_response']
 
-ALLOWED_LOGIN_TYPES = ('password', 'oauth', 'oauth2', 'openid-direct', 'openid-username', 'wordpress')
+ALLOWED_LOGIN_TYPES = (
+    'password', 'oauth', 'oauth2',
+    'openid-direct', 'openid-username', 'wordpress',
+    'discourse-site'
+)
 
 def email_is_blacklisted(email):
     patterns = askbot_settings.BLACKLISTED_EMAIL_PATTERNS
@@ -424,7 +426,7 @@ def get_enabled_major_login_providers():
       and consumer secret. The purpose of this function is to hide the differences
       between the ways user id is accessed from the different OAuth providers
     """
-    data = SortedDict()
+    data = OrderedDict()
 
     if use_password_login():
         site_name = askbot_settings.APP_SHORT_NAME
@@ -471,6 +473,58 @@ def get_enabled_major_login_providers():
             'scope': ['email',],
         }
 
+    if askbot_settings.YAMMER_KEY and askbot_settings.YAMMER_SECRET:
+        data['yammer'] = {
+            'name': 'yammer',
+            'display_name': 'Yammer',
+            'type': 'oauth2',
+            'auth_endpoint': 'https://www.yammer.com/dialog/oauth',
+            'token_endpoint': 'https://www.yammer.com/oauth2/access_token',
+            'resource_endpoint': 'https://www.yammer.com/api/v1/users/current.json',
+            'icon_media_path': 'images/jquery-openid/yammer.png',
+            'get_user_id_function': lambda data: data.user['id'],
+            'response_parser': lambda data: simplejson.loads(data),
+        }
+
+    if askbot_settings.WINDOWS_LIVE_KEY and askbot_settings.WINDOWS_LIVE_SECRET:
+        data['windows-live'] = {
+            'name': 'windows-live',
+            'display_name': 'Windows Live',
+            'type': 'oauth2',
+            'auth_endpoint': 'https://login.live.com/oauth20_authorize.srf',
+            'token_endpoint': 'https://login.live.com/oauth20_token.srf',
+            'resource_endpoint': 'https://apis.live.net/v5.0/me',
+            'icon_media_path': 'images/jquery-openid/windows-live.png',
+            'get_user_id_function': lambda data: data.user_id,
+            'response_parser': lambda data: simplejson.loads(data),
+            'extra_auth_params': {'scope': ('wl.basic',)},
+        }
+
+    def get_microsoft_azure_user_id(client):
+        conn = httplib.HTTPSConnection('graph.microsoft.com')
+        headers = {
+            'Authorization' : 'Bearer {0}'.format(client.access_token),
+            'Accept' : 'application/json',
+        }
+        conn.request('GET', '/v1.0/me', '', headers)
+        response = conn.getresponse()
+        profile = simplejson.loads(response.read())
+        return profile['id']
+
+    if askbot_settings.MICROSOFT_AZURE_KEY and askbot_settings.MICROSOFT_AZURE_SECRET:
+        data['microsoft-azure'] = {
+            'name': 'microsoft-azure',
+            'display_name': 'Microsoft Azure',
+            'type': 'oauth2',
+            'auth_endpoint': 'https://login.microsoftonline.com/common/oauth2/v2.0/authorize',
+            'token_endpoint': 'https://login.microsoftonline.com/common/oauth2/v2.0/token',
+            'resource_endpoint': 'https://graph.microsoft.com/v1.0/',
+            'icon_media_path': 'images/jquery-openid/microsoft-azure.png',
+            'get_user_id_function': get_microsoft_azure_user_id,
+            'response_parser': lambda data: simplejson.loads(data),
+            'extra_auth_params': {'scope': ('User.Read',),},
+        }
+
     if askbot_settings.SIGNIN_FEDORA_ENABLED:
         data['fedora'] = {
             'name': 'fedora',
@@ -480,6 +534,14 @@ def get_enabled_major_login_providers():
             'icon_media_path': 'images/jquery-openid/fedora.gif'
         }
 
+    if askbot_settings.SIGNIN_DISCOURSE_ENABLED:
+        data['discourse'] = {
+            'name': 'discourse',
+            'display_name': 'Discourse',
+            'type': 'discourse',
+            'icon_media_path': 'images/jquery-openid/discourse-button.png'
+        }
+
     if askbot_settings.TWITTER_KEY and askbot_settings.TWITTER_SECRET:
         data['twitter'] = {
             'name': 'twitter',
@@ -633,7 +695,7 @@ def get_enabled_minor_login_providers():
 
     structure of dictionary values is the same as in get_enabled_major_login_providers
     """
-    data = SortedDict()
+    data = OrderedDict()
     #data['myopenid'] = {
     #    'name': 'myopenid',
     #    'display_name': 'MyOpenid',
@@ -820,6 +882,15 @@ def get_oauth_parameters(provider_name):
     elif provider_name == 'facebook':
         consumer_key = askbot_settings.FACEBOOK_KEY
         consumer_secret = askbot_settings.FACEBOOK_SECRET
+    elif provider_name == 'yammer':
+        consumer_key = askbot_settings.YAMMER_KEY
+        consumer_secret = askbot_settings.YAMMER_SECRET
+    elif provider_name == 'windows-live':
+        consumer_key = askbot_settings.WINDOWS_LIVE_KEY
+        consumer_secret = askbot_settings.WINDOWS_LIVE_SECRET
+    elif provider_name == 'microsoft-azure':
+        consumer_key = askbot_settings.MICROSOFT_AZURE_KEY
+        consumer_secret = askbot_settings.MICROSOFT_AZURE_SECRET
     elif provider_name != 'mediawiki':
         raise ValueError('unexpected oauth provider %s' % provider_name)
 
@@ -840,7 +911,7 @@ class OAuthConnection(object):
         if provider_name == 'mediawiki':
             return providers.mediawiki.Provider()
         else:
-            return super(OAuthConnection, cls).__new__(cls, provider_name)
+            return super(OAuthConnection, cls).__new__(cls)
 
     def __init__(self, provider_name):
         """initializes oauth connection
@@ -1008,6 +1079,7 @@ def get_oauth2_starter_url(provider_name, csrf_token):
         client_id=client_id,
         redirect_uri=redirect_uri
     )
+    
     return client.auth_uri(state=csrf_token, **params.get('extra_auth_params', {}))
 
 
@@ -1018,7 +1090,7 @@ def ldap_check_password(username, password):
         ldap_session.simple_bind_s(username, password)
         ldap_session.unbind_s()
         return True
-    except ldap.LDAPError, e:
+    except ldap.LDAPError as e:
         logging.critical(unicode(e))
         return False
 
