@@ -35,14 +35,13 @@ import datetime
 from django.http import HttpResponseRedirect, Http404
 from django.http import HttpResponse
 from django.http import HttpResponseBadRequest
-from django.template import RequestContext, Context
+from django.template import RequestContext
 from django.conf import settings as django_settings
 from askbot.conf import settings as askbot_settings
 from django.contrib.auth.models import User
 from django.contrib.auth.decorators import login_required
 from django.contrib.auth import authenticate
 from django.core.urlresolvers import reverse
-from django.forms.util import ErrorList
 from django.shortcuts import render
 from django.template.loader import get_template
 from django.views.decorators import csrf
@@ -52,13 +51,14 @@ from askbot.utils.functions import generate_random_key, encode_jwt
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
 from django.utils.safestring import mark_safe
-from django.utils import simplejson
-from askbot.mail.messages import EmailValidation
+import simplejson
+from askbot.mail.messages import AccountActivation, AccountRecovery
 from askbot.utils import decorators as askbot_decorators
 from askbot.utils.functions import format_setting_name
 from askbot.utils.html import site_url
 from askbot.deps.django_authopenid.ldap_auth import ldap_create_user
 from askbot.deps.django_authopenid.ldap_auth import ldap_authenticate
+from askbot.deps.django_authopenid.providers import discourse
 from askbot.deps.django_authopenid.exceptions import OAuthError
 from askbot.middleware.anon_user import connect_messages_to_anon_user
 from askbot.utils.loading import load_module
@@ -186,7 +186,7 @@ def logout_page(request):
         'page_class': 'meta',
         'have_federated_login_methods': util.have_enabled_federated_login_methods()
     }
-    return render(request, 'authopenid/logout.html', Context(data))
+    return render(request, 'authopenid/logout.html', data)
 
 def get_url_host(request):
     if request.is_secure():
@@ -243,6 +243,39 @@ def not_authenticated(func):
     return decorated
 
 
+def complete_discourse_signin(request):
+    """Logs in a discourse user, creates an account, if needed"""
+    discourse_login_session = request.session.get('discourse_login')
+    nonce = discourse_login_session.get('nonce', None)
+    from askbot.deps.django_authopenid.providers import discourse
+    form = discourse.DiscourseSsoForm(request.REQUEST, nonce=nonce)
+    next_url = discourse_login_session.get('success_url', reverse('questions'))
+    if not form.is_valid():
+        # if form is invalid - show login screen with error message
+        info = unicode(form.errors).encode('utf-8')
+        logging.error('Could not aunenticate via a Discourse site %s', info)
+        login_form = forms.LoginForm(initial={'next': next_url})
+        message = _('Unfortunately, there was some problem logging in via the Discourse site')
+        request.user.message_set.create(message=message)
+        return show_signin_view(request, login_form=login_form)
+
+    sso_data = form.get_sso_data()
+    user_identifier = sso_data['username'] + '@discourse'
+
+    user = authenticate(method='identifier',
+                        user_identifier=user_identifier,
+                        provider_name='discourse')
+
+    request.session['username'] = sso_data['username']
+    request.session['email'] = sso_data['email']
+
+    return finalize_generic_signin(request=request,
+                                   user=user,
+                                   user_identifier=user_identifier,
+                                   login_provider_name='discourse',
+                                   redirect_url=next_url)
+
+
 def complete_oauth2_signin(request):
     next_url = get_next_url_from_session(request.session)
 
@@ -430,7 +463,7 @@ def complete_oauth1_signin(request):
         request.session['username'] = oauth.get_username()
 
         logging.debug('have %s user id=%s' % (oauth_provider_name, user_id))
-    except Exception, e:
+    except Exception as e:
         logging.critical(e)
         msg = _('Unfortunately, there was some problem when '
                 'connecting to %(provider)s, please try again '
@@ -467,8 +500,6 @@ def signin(request, template_name='authopenid/signin.html'):
     template : authopenid/signin.htm
     """
     logging.debug('in signin view')
-    on_failure = signin_failure
-
     #we need a special priority on where to redirect on successful login
     #here:
     #1) url parameter "next" - if explicitly set
@@ -519,7 +550,7 @@ def signin(request, template_name='authopenid/signin.html'):
                         if user_info['success']:
                             if askbot_settings.LDAP_AUTOCREATE_USERS:
                                 #create new user or
-                                user = ldap_create_user(user_info).user
+                                user = ldap_create_user(user_info, request).user
                                 user = authenticate(method='force', user_id=user.pk)
                                 assert(user is not None)
                                 login(request, user)
@@ -585,6 +616,9 @@ def signin(request, template_name='authopenid/signin.html'):
                         )
                         raise Http404
 
+            elif login_form.cleaned_data['login_type'] == 'discourse':
+                return HttpResponseRedirect(discourse.get_sso_login_url(request, next_url))
+
             elif login_form.cleaned_data['login_type'] == 'mozilla-persona':
                 assertion = login_form.cleaned_data['persona_assertion']
                 email = util.mozilla_persona_get_email_from_assertion(assertion)
@@ -663,7 +697,7 @@ def signin(request, template_name='authopenid/signin.html'):
                     oauth_url = connection.get_auth_url(login_only=True)
                     return HttpResponseRedirect(oauth_url)
 
-                except util.OAuthError, e:
+                except util.OAuthError as e:
                     logging.critical(unicode(e))
                     msg = _('Unfortunately, there was some problem when '
                             'connecting to %(provider)s, please try again '
@@ -679,7 +713,7 @@ def signin(request, template_name='authopenid/signin.html'):
                     request.session['provider_name'] = provider_name
                     request.session['next_url'] = next_url
                     return HttpResponseRedirect(redirect_url)
-                except util.OAuthError, e:
+                except util.OAuthError as e:
                     logging.critical(unicode(e))
                     msg = _('Unfortunately, there was some problem when '
                             'connecting to %(provider)s, please try again '
@@ -709,7 +743,7 @@ def signin(request, template_name='authopenid/signin.html'):
                                     login_provider_name=provider_name,
                                     redirect_url=next_url
                                 )
-                except WpFault, e:
+                except WpFault as e:
                     logging.critical(unicode(e))
                     msg = _('The login password combination was not correct')
                     request.user.message_set.create(message = msg)
@@ -879,7 +913,7 @@ def show_signin_view(
     data['major_login_providers'] = major_login_providers.values()
     data['minor_login_providers'] = minor_login_providers.values()
 
-    return render(request, template_name, Context(data))
+    return render(request, template_name, data)
 
 @csrf.csrf_protect
 @askbot_decorators.post_only
@@ -907,17 +941,17 @@ def delete_login_method(request):
                                                 provider_name = provider_name
                                             )
             login_method.delete()
-            return HttpResponse('', mimetype = 'application/json')
+            return HttpResponse('', content_type='application/json')
         except UserAssociation.DoesNotExist:
             #error response
             message = _('Login method %(provider_name)s does not exist')
-            return HttpResponse(message, status=500, mimetype = 'application/json')
+            return HttpResponse(message, status=500, content_type='application/json')
         except UserAssociation.MultipleObjectsReturned:
             logging.critical(
                     'have multiple %(provider)s logins for user %(id)s'
                 ) % {'provider':provider_name, 'id': request.user.id}
             message = _('Oops, sorry - there was some error - please try again')
-            return HttpResponse(message, status=500, mimetype = 'application/json')
+            return HttpResponse(message, status=500, content_type='application/json')
     else:
         raise Http404
 
@@ -1077,7 +1111,7 @@ def finalize_generic_signin(
 
 @not_authenticated
 @csrf.csrf_protect
-def register(request, login_provider_name=None, 
+def register(request, login_provider_name=None,
     user_identifier=None, redirect_url=None):
     """
     this function is used via it's own url with request.method=POST
@@ -1196,7 +1230,7 @@ def register(request, login_provider_name=None,
                 #they can override the default provided by LDAP
                 user_info['django_username'] = username
                 user_info['email'] = email
-                user = ldap_create_user(user_info).user
+                user = ldap_create_user(user_info, request).user
                 user = authenticate(user_id=user.id, method='force')
                 del request.session['ldap_user_info']
                 login(request, user)
@@ -1222,7 +1256,7 @@ def register(request, login_provider_name=None,
                                         'login_provider_name': login_provider_name}
                 email_verifier.save()
                 send_email_key(email, email_verifier.key,
-                               handler_url_name='verify_email_and_register')
+                               email_type='verify_email_and_register')
                 next_jwt = encode_jwt({'next_url': next_url})
                 redirect_url = reverse('verify_email_and_register') + '?next=' + next_jwt
                 return HttpResponseRedirect(redirect_url)
@@ -1250,7 +1284,7 @@ def register(request, login_provider_name=None,
         'login_type':'openid',
         'gravatar_faq_url':reverse('faq') + '#gravatar',
     }
-    return render(request, 'authopenid/complete.html', Context(data))
+    return render(request, 'authopenid/complete.html', data)
 
 def signin_failure(request, message):
     """
@@ -1308,7 +1342,8 @@ def verify_email_and_register(request):
             cleanup_post_register_session(request)
 
             return HttpResponseRedirect(get_next_url(request))
-        except Exception: #pylint: disable=broad-except
+        except Exception as error: #pylint: disable=broad-except
+            logging.critical('Could not verify account: %s', unicode(error).encode('utf-8'))
             message = _(
                 'Sorry, registration failed. '
                 'The token can be already used or has expired. Please try again'
@@ -1317,7 +1352,7 @@ def verify_email_and_register(request):
             return HttpResponseRedirect(reverse('index'))
     else:
         data = {'page_class': 'validate-email-page'}
-        return render(request, 'authopenid/verify_email.html', Context(data))
+        return render(request, 'authopenid/verify_email.html', data)
 
 @not_authenticated
 @csrf.csrf_protect
@@ -1357,10 +1392,9 @@ def signup_with_password(request):
                                         'login_provider_name': 'local',
                                         'email': email, 'password': password}
                 email_verifier.save()
-                send_email_key(
-                    email, email_verifier.key,
-                    handler_url_name='verify_email_and_register'
-                )
+
+                send_email_key(email, email_verifier.key,
+                               email_type='verify_email_and_register')
                 redirect_url = reverse('verify_email_and_register') + \
                                 '?next=' + get_next_jwt(request)
                 return HttpResponseRedirect(redirect_url)
@@ -1381,7 +1415,7 @@ def signup_with_password(request):
     return render(
         request,
         'authopenid/signup_with_password.html',
-        Context(context_data)
+        context_data
     )
 
 @login_required
@@ -1426,16 +1460,19 @@ def set_new_email(user, new_email):
         user.email_isvalid = False
         user.save()
 
-def send_email_key(address, key, handler_url_name='user_account_recover'):
+def send_email_key(address, key, email_type='user_account_recover'):
     """private function. sends email containing validation key
     to user's email address
     """
-    email = EmailValidation({
-        'handler_url_name': handler_url_name,
-        'key': key
-    })
-    email.send([address,])
+    if email_type == 'user_account_recover':
+        email_class = AccountRecovery
+    elif email_type == 'verify_email_and_register':
+        email_class = AccountActivation
+    else:
+        raise ValueError('Unrecognized email_type=%s', email_type)
 
+    email = email_class({'key': key})
+    email.send([address,])
 
 def send_user_new_email_key(user):
     user.email_key = generate_random_key()
@@ -1454,54 +1491,52 @@ def recover_account(request):
     """
     if not askbot_settings.ALLOW_ACCOUNT_RECOVERY_BY_EMAIL:
         raise Http404
-    if request.method == 'POST':
+    if request.method == 'POST' and 'validation_code' not in request.POST:
         form = forms.AccountRecoveryForm(request.POST)
         if form.is_valid():
             user = form.cleaned_data['user']
             send_user_new_email_key(user)
-            message = _(
-                    'Please check your email and visit the enclosed link.'
-                )
-            return show_signin_view(
-                            request,
-                            account_recovery_message = message,
-                            view_subtype = 'email_sent'
-                        )
-        else:
-            return show_signin_view(
-                            request,
-                            account_recovery_form = form
-                        )
-    else:
-        key = request.GET.get('validation_code', None)
-        if key is None:
-            return HttpResponseRedirect(reverse('user_signin'))
+            message = _('Please check your email and visit the enclosed link.')
+            data = {'page_class': 'validate-email-page'}
+            return render(request, 'authopenid/verify_email.html', data)
+        return show_signin_view(request, account_recovery_form=form)
 
-        user = authenticate(email_key=key, method='email_key')
-        if user:
-            if request.user.is_authenticated():
-                if user != request.user:
-                    logout(request)
-                    login(request, user)
-            else:
-                login(request, user)
+    key = request.REQUEST.get('validation_code', None)
+    return auth_user_by_token(request, key)
 
-            from askbot.models import greet_new_user
-            greet_new_user(user)
+def auth_user_by_token(request, key):
+    """Non-view function.
+    Try to log in user via account recovery `key`.
+    This key is normally sent to the user to help recover account by email.
 
-            #need to show "sticky" signin view here
-            request.session['in_recovery'] = True
-            return show_signin_view(
-                                request,
-                                view_subtype='add_openid',
-                                sticky=True
-                            )
-        else:
-            data = {
-                'account_recovery_form': forms.AccountRecoveryForm(),
-                'message': _('Sorry, this account recovery key has expired or is invalid'),
-                'bad_key': True
-            }
-            return render(request, 'authopenid/recover_account.html', data)
+    In the case of success - logs in
+    and shows user the current login methods,
+    so that user has a chance to change the password or
+    add an authentication method.
 
-        return HttpResponseRedirect(get_next_url(request))
+    TODO: instead of using sub-branch of the login view
+    create a dedicated view.
+
+    In the case of failure - redirects to the authentication page
+    """
+
+    if key is None:
+        return HttpResponseRedirect(reverse('user_signin'))
+
+    user = authenticate(email_key=key, method='email_key')
+    if user:
+        if request.user.is_authenticated() and user != request.user:
+            logout(request)
+        login(request, user)
+        from askbot.models import greet_new_user
+        greet_new_user(user)
+        #need to show "sticky" signin view here
+        request.session['in_recovery'] = True
+        return show_signin_view(request, view_subtype='add_openid', sticky=True)
+
+    data = {
+        'account_recovery_form': forms.AccountRecoveryForm(),
+        'message': _('Sorry, this account recovery key has expired or is invalid'),
+        'bad_key': True
+    }
+    return render(request, 'authopenid/recover_account.html', data)
