@@ -1,12 +1,10 @@
 from django.core.management.base import NoArgsCommand
 from askbot.models import User
 from askbot.utils.console import ProgressBar
-from group_messaging.models import get_unread_inbox_counter
-from django.db import transaction
+from askbot.deps.group_messaging.models import get_unread_inbox_counter
 
 class Command(NoArgsCommand):
 
-    @transaction.commit_manually
     def handle_noargs(self, *args, **kwargs):
         users = User.objects.all()
         count = users.count()
@@ -15,4 +13,3 @@ class Command(NoArgsCommand):
             counter = get_unread_inbox_counter(user)
             counter.recalculate()
             counter.save()
-            transaction.commit()
