@@ -1,16 +1,16 @@
+from askbot.deps.group_messaging.models import LastVisitTime
+from askbot.deps.group_messaging.models import Message
+from askbot.deps.group_messaging.models import MessageMemo
+from askbot.deps.group_messaging.models import SenderList
+from askbot.deps.group_messaging.models import create_personal_group
+from askbot.deps.group_messaging.models import get_personal_group
+from askbot.deps.group_messaging.models import get_unread_inbox_counter
+from askbot.deps.group_messaging.views import ThreadsList
 from askbot.tests.utils import with_settings
 from bs4 import BeautifulSoup
 from django.contrib.auth.models import User, Group
 from django.test import TestCase
-from group_messaging.models import LastVisitTime
 from django.utils import timezone
-from group_messaging.models import Message
-from group_messaging.models import MessageMemo
-from group_messaging.models import SenderList
-from group_messaging.models import create_personal_group
-from group_messaging.models import get_personal_group
-from group_messaging.models import get_unread_inbox_counter
-from group_messaging.views import ThreadsList
 from mock import Mock
 import time
 import urlparse
@@ -167,13 +167,13 @@ class ViewsTests(GroupMessagingTests):
         root = self.create_thread_for_user(self.sender, self.recipient)
         from django.core.mail import outbox
         html_message = get_html_message(outbox[0])
-        link = BeautifulSoup(html_message).find('a', attrs={'class': 'thread-link'})
+        link = BeautifulSoup(html_message, 'html5lib').find('a', attrs={'class': 'thread-link'})
         url = link['href'].replace('&amp;', '&')
         parsed_url = urlparse.urlparse(url)
         url_data = urlparse.parse_qsl(parsed_url.query)
         self.client.login(user_id=self.recipient.id, method='force')
         response = self.client.get(parsed_url.path, url_data)
-        dom = BeautifulSoup(response.content)
+        dom = BeautifulSoup(response.content, 'html5lib')
         threads = dom.find_all('ul', attrs={'class': 'js-thread'})
         self.assertEquals(len(threads), 1)
         thread_lists = dom.find_all('table', attrs={'class': 'js-thread-list'})
@@ -353,7 +353,7 @@ class ModelsTests(GroupMessagingTests):
         self.assertEqual(outbox[0].recipients()[0], self.recipient.email)
         html_message = get_html_message(outbox[0])
         self.assertTrue(root.text in html_message)
-        soup = BeautifulSoup(html_message)
+        soup = BeautifulSoup(html_message, 'html5lib')
         links = soup.find_all('a', attrs={'class': 'thread-link'})
         self.assertEqual(len(links), 1)
         parse_result = urlparse.urlparse(links[0]['href'])
