@@ -4,12 +4,12 @@
 http://code.google.com/p/django-values/
 """
 from decimal import Decimal
+from collections import OrderedDict
 from django import forms
 from django.conf import settings as django_settings
 from django.core.exceptions import ImproperlyConfigured
 from django.core.cache import cache
-from django.utils import simplejson
-from django.utils.datastructures import SortedDict
+import simplejson
 from django.utils.encoding import force_unicode
 from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext as _
@@ -41,25 +41,101 @@ NOTSET = object()
 def get_language():
     return _get_language() or django_settings.LANGUAGE_CODE
 
-class SortedDotDict(SortedDict):
+
+class SortedDotDict(object):
+    def __init__(self, *args, **kwargs):
+        super(SortedDotDict, self).__init__(*args, **kwargs)
+        self._dict = OrderedDict()
+
+    def __contains__(self, *args, **kwargs):
+        return self._dict.__contains__(*args, **kwargs)
+
+    def __eq__(self, *args, **kwargs):
+        return self._dict.__eq__(*args, **kwargs)
+
+    def __format__(self, *args, **kwargs):
+        return self._dict.__format__(*args, **kwargs)
+
+    def __ge__(self, *args, **kwargs):
+        return self._dict.__ge__(*args, **kwargs)
 
     def __getattr__(self, key):
         try:
-            return self[key]
+            return self._dict[key]
         except:
-            raise AttributeError, key
+            raise AttributeError(key)
 
     def __iter__(self):
         vals = self.values()
         for k in vals:
             yield k
 
+    def __getitem__(self, key):
+        return self._dict[key]
+
+    def __setitem__(self, key, value):
+        self._dict[key] = value
+
+    def __delitem__(self, key):
+        del self._dict[key]
+
+    def keys(self):
+        return self._dict.keys()
+
     def values(self):
-        vals = super(SortedDotDict, self).values()
+        vals = self._dict.values()
         vals = [v for v in vals if isinstance(v, (ConfigurationGroup, Value))]
         vals.sort()
         return vals
 
+    def items(self):
+        return self._dict.items()
+
+    def iterkeys(self):
+        return self._dict.iterkeys()
+
+    def itervalues(self):
+        return self._dict.itervalues()
+
+    def iteritems(self):
+        return self._dict.iteritems()
+
+    def get(self, *args, **kwargs):
+        return self._dict.get(*args, **kwargs)
+
+    def clear(self):
+        return self._dict.clear()
+
+    def copy(self):
+        s = SortedDotDict()
+        s._dict = self._dict.copy()
+        return s
+
+    def fromkeys(self):
+        return self._dict.fromkeys()
+
+    def has_key(self, key):
+        return key in self._dict
+
+    def pop(self, *args, **kwargs):
+        return self._dict.pop(*args, **kwargs)
+
+    def popitem(self, *args, **kwargs):
+        return self._dict.popitem(*args, **kwargs)
+
+    def setdefault(self, key, default):
+        return self._dict.setdefault(key, default)
+
+    def update(self, d):
+        return self._dict.update(d)
+
+    def viewitems(self, *args, **kwargs):
+        return self._dict.viewitems(*args, **kwargs)
+
+    def viewvalues(self, *args, **kwargs):
+        return self._dict.viewvalues(*args, **kwargs)
+
+
 class SuperGroup(object):
     """Aggregates ConfigurationGroup's into super-groups
     that are used only for the presentation in the UI"""
@@ -241,7 +317,7 @@ class Value(object):
     choice_values = property(fget=_choice_values)
 
     def copy(self):
-        new_value = self.__class__(self.key)
+        new_value = self.__class__(self.group, self.key)
         new_value.__dict__ = self.__dict__.copy()
         return new_value
 
@@ -293,10 +369,10 @@ class Value(object):
 
     def make_fields(self, **kwargs):
         if self.localized:
-            langs_dict = SortedDict(django_settings.LANGUAGES)
+            langs_dict = OrderedDict(django_settings.LANGUAGES)
             default_code = django_settings.LANGUAGE_CODE
             default_name = langs_dict[default_code]
-            langs_dict.insert(0, default_code, default_name)
+            langs_dict[0] = default_code, default_name
             langs = langs_dict.keys()
         else:
             langs = (django_settings.LANGUAGE_CODE,)
@@ -318,11 +394,15 @@ class Value(object):
 
         return fields
 
+    def make_setting_with_value(self, value, language_code=None):
+        db_value = self.get_db_prep_save(value)
+        return self.make_setting(db_value, language_code=language_code)
+
     def make_setting(self, db_value, language_code=None):
         log.debug('new setting %s.%s', self.group.key, self.key)
         key = self.key
-        if self.localized and language_code:
-            key += '_' + format_setting_name(language_code)
+        if self.localized:
+            key += '_' + format_setting_name(language_code or get_language())
         return Setting(group=self.group.key, key=key, value=db_value)
 
     def _setting(self):
@@ -362,7 +442,7 @@ class Value(object):
             try:
                 val = self.setting.value
 
-            except SettingNotSet, sns:
+            except SettingNotSet as sns:
 
                 if self.localized and lang == django_settings.LANGUAGE_CODE:
                     try:
@@ -381,12 +461,12 @@ class Value(object):
                 else:
                     val = NOTSET
 
-            except AttributeError, ae:
+            except AttributeError as ae:
                 log.error("Attribute error: %s", ae)
                 log.error("%s: Could not get _value of %s", key, self.setting)
                 raise(ae)
 
-            except Exception, e:
+            except Exception as e:
                 global _WARN
                 log.error(e)
                 if str(e).find("configuration_setting") > -1:
@@ -553,7 +633,7 @@ class DecimalValue(Value):
 
         try:
             return Decimal(value)
-        except TypeError, te:
+        except TypeError as te:
             log.warning("Can't convert %s to Decimal for settings %s.%s", value, self.group.key, self.key)
             raise TypeError(te)
 
@@ -677,6 +757,10 @@ class StringValue(Value):
             self.language_code = kwargs.pop('language_code', django_settings.LANGUAGE_CODE)
             forms.CharField.__init__(self, *args, **kwargs)
 
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('default', '')
+        super(StringValue, self).__init__(*args, **kwargs)
+
     def to_python(self, value):
         if value == NOTSET:
             value = ""
@@ -702,6 +786,10 @@ class LongStringValue(Value):
             self.language_code = kwargs.pop('language_code', django_settings.LANGUAGE_CODE)
             forms.CharField.__init__(self, *args, **kwargs)
 
+    def __init__(self, *args, **kwargs):
+        kwargs.setdefault('default', '')
+        super(LongStringValue, self).__init__(*args, **kwargs)
+
     def make_setting(self, db_value, language_code=None):
         log.debug('new long setting %s.%s', self.group.key, self.key)
         key = self.key
@@ -756,7 +844,7 @@ class ImageValue(StringValue):
     def make_field(self, **kwargs):
         kwargs['url_resolver'] = self.url_resolver
         kwargs['allowed_file_extensions'] = self.allowed_file_extensions
-        return super(StringValue, self).make_field(**kwargs)
+        return super(ImageValue, self).make_field(**kwargs)
 
     def update(self, uploaded_file, language_code=None):
         """uploaded_file is an instance of
@@ -842,7 +930,7 @@ class ModuleValue(Value):
         """Load a child module"""
         value = self._value()
         if value == NOTSET:
-            raise SettingNotSet("%s.%s", self.group.key, self.key)
+            raise SettingNotSet("%s.%s" % (self.group.key, self.key))
         else:
             return load_module("%s.%s" % (value, module))
 
