@@ -1,3 +1,4 @@
+from __future__ import print_function
 from askbot.deps.django_authopenid.models import UserAssociation
 from askbot.management.commands.base import BaseImportXMLCommand
 from askbot.models import Award
@@ -8,6 +9,7 @@ from askbot.models import Thread
 from askbot.models import Tag
 from askbot.models import User
 from askbot.utils.slug import slugify_camelcase
+from askbot import const
 from bs4 import BeautifulSoup
 from datetime import datetime
 from django.db.models import Q
@@ -183,7 +185,7 @@ class Command(BaseImportXMLCommand):
         for profile in self.get_objects_for_model('forum.user'):
             user = self.get_imported_object_by_old_id(User, profile.id)
             self.copy_bool_parameter(profile, user, 'email_isvalid')
-            user.reputation = max(user.reputation + profile.reputation - 1, 1)
+            user.receive_reputation(profile.reputation - const.MIN_REPUTATION)
             user.gold += profile.gold
             user.silver += profile.silver
             user.bronze += profile.bronze
@@ -192,8 +194,8 @@ class Command(BaseImportXMLCommand):
             self.copy_string_parameter(profile, user, 'website')
             self.copy_string_parameter(profile, user, 'location')
             self.copy_numeric_parameter(profile, user, 'date_of_birth')
-            self.copy_string_parameter(profile, user, 'about')
             user.save()
+            user.update_localized_profile(about=profile.about)
 
     def import_user_logins(self):
         """import user's login methods from OSQA to Askbot"""
@@ -238,7 +240,7 @@ class Command(BaseImportXMLCommand):
             try:
                 askbot_badge = BadgeData.objects.get(slug=badge_slug)
             except BadgeData.DoesNotExist:
-                print 'Could not find an equivalent to badge %s in Askbot' % osqa_badge.cls
+                print('Could not find an equivalent to badge %s in Askbot' % osqa_badge.cls)
                 continue
             self.log_action(osqa_badge, askbot_badge)
         """
@@ -270,7 +272,7 @@ class Command(BaseImportXMLCommand):
             badge = self.get_imported_object_by_old_id(BadgeData, osqa_award.badge)
             if badge is None:
                 continue
-            print 'awarding badge %s' % badge.slug
+            print('awarding badge %s' % badge.slug)
             #if multiple or user does not have this badge, then award
             if badge.is_multiple() or (not user.has_badge(badge)):
                 award = Award()
