@@ -1,6 +1,6 @@
 """Replaces django-avatar 'rebuild_avatars'
 and saves cached active avatar urls for each user"""
-from askbot.models import User
+from askbot.models import User, UserProfile
 from askbot.utils.console import ProgressBar
 from avatar.conf import settings as avatar_settings
 from avatar.models import Avatar
@@ -20,6 +20,7 @@ class Command(NoArgsCommand):
         count = users.count()
         message = 'Rebuilding cached avatar urls'
         for user in ProgressBar(users.iterator(), count, message):
-            #recalculate is done on pre_save
             user.init_avatar_urls()
-            User.objects.filter(id=user.id).update(avatar_urls=user.avatar_urls)
+            UserProfile.objects.filter(auth_user_ptr=user).update(avatar_urls=user.avatar_urls)
+            profile = UserProfile.objects.get(pk=user.pk)
+            profile.update_cache()
