@@ -1,5 +1,3 @@
-from optparse import make_option
-
 from django.core.management.base import BaseCommand
 from django.conf import settings as django_settings
 from django.utils import translation
@@ -9,14 +7,14 @@ from askbot.utils.console import ProgressBar
 
 
 class Command(BaseCommand):
-    option_list = BaseCommand.option_list + (
-        make_option(
+
+    def add_arguments(self, parser):
+        parser.add_argument(
             '-l',
             '--language',
             action='append',
             help='Specify the languages for which the cache has to be rebuilt.'
-        ),
-    )
+        )
 
     def handle(self, **options):
         languages = options['language'] or (django_settings.LANGUAGE_CODE,)
