@@ -1,9 +1,9 @@
 """management command that creates a tag synonym
 all corresponding questions are retagged
 """
+from __future__ import print_function
 
 import sys
-from optparse import make_option
 from django.conf import settings as django_settings
 from django.core import management
 from django.core.management.base import BaseCommand, CommandError
@@ -13,49 +13,42 @@ from askbot.management.commands.rename_tags import get_admin
 from askbot.utils import console
 
 
-
-def decode_input(input):
-    decoded_input = input.decode(sys.stdin.encoding)
-    decoded_input = decoded_input.strip()
-    return decoded_input
-
-
 class Command(BaseCommand):
 
     help = """create TagSynonym,
 retags questions from source_tag_name to target_tag_name,
 remove source_tag"""
 
-    option_list = BaseCommand.option_list + (
-        make_option('--from',
-            action = 'store',
-            type = 'str',
-            dest = 'from',
-            default = None,
-            help = 'a source tag name which needs to be replaced'
-        ),
-        make_option('--to',
-            action = 'store',
-            type = 'str',
-            dest = 'to',
-            default = None,
-            help = 'a target tag name that are to be used instead'
-        ),
-        make_option('--user-id',
-            action = 'store',
-            type = 'int',
-            dest = 'user_id',
-            default = None,
-            help = 'id of the user who will be marked as a performer of this operation'
-        ),
-        make_option('--lang',
-            action='store',
-            type='str',
-            dest='lang',
-            default=django_settings.LANGUAGE_CODE,
-            help='language code of the tag, e.g. "en"'
-        )
-    )
+    def add_arguments(self, parser):
+
+        parser.add_argument('--from',
+                            action='store',
+                            type=str,
+                            dest='from',
+                            default=None,
+                            help='a source tag name which needs to be replaced'
+                           )
+        parser.add_argument('--to',
+                            action='store',
+                            type=str,
+                            dest='to',
+                            default=None,
+                            help='a target tag name that are to be used instead'
+                           )
+        parser.add_argument('--user-id',
+                            action='store',
+                            type=int,
+                            dest='user_id',
+                            default=None,
+                            help='id of the user who will be marked as a performer of this operation'
+                           )
+        parser.add_argument('--lang',
+                            action='store',
+                            type=str,
+                            dest='lang',
+                            default=django_settings.LANGUAGE_CODE,
+                            help='language code of the tag, e.g. "en"'
+                           )
 
     def handle(self, *args, **options):
         """command handle function. reads tag names, decodes
@@ -71,8 +64,8 @@ remove source_tag"""
         if options['to'] is None:
             raise CommandError('the --to argument is required')
 
-        source_tag_name = decode_input(options['from'])
-        target_tag_name = decode_input(options['to'])
+        source_tag_name = console.decode_input(options['from'])
+        target_tag_name = console.decode_input(options['to'])
 
         if source_tag_name == target_tag_name:
             raise CommandError("source and target tags appear to be the same")
@@ -90,7 +83,7 @@ remove source_tag"""
     %s ==> %s?""" % (source_tag_name, source_tag_name, target_tag_name)
                 choice = console.choice_dialog(prompt, choices=('yes', 'no'))
                 if choice == 'no':
-                    print 'Cancled'
+                    print('Cancled')
                     sys.exit()
             source_tag = models.Tag.objects.create(
                                             name=source_tag_name,
@@ -113,7 +106,7 @@ remove source_tag"""
                                                                          source_tag_name, tag_synonym_tmp.target_tag_name)
                 choice = console.choice_dialog(prompt, choices=('yes', 'no'))
                 if choice == 'no':
-                    print 'Cancled'
+                    print('Cancled')
                     sys.exit()
             target_tag_name = tag_synonym_tmp.target_tag_name
             options['to'] = target_tag_name
