@@ -5,7 +5,7 @@ from askbot import models
 import sys
 
 class Command(NoArgsCommand):
-    @transaction.commit_manually
+
     def handle_noargs(self, **options):
         user = models.User.objects.get(id=2)
         for i in xrange(1000):
@@ -17,4 +17,3 @@ class Command(NoArgsCommand):
                             )
             if i % 1000 == 0:
                 transaction.commit()
-        transaction.commit()
