@@ -1,5 +1,6 @@
 """the management command that outputs configuration
 for sphinx search"""
+from __future__ import print_function
 from django.conf import settings
 from django.core.management.base import BaseCommand
 from django.template import Template, Context
@@ -11,8 +12,8 @@ class Command(BaseCommand):
         tpl_file = open(askbot.get_path_to('search/sphinx/sphinx.conf'))
         tpl = Template(tpl_file.read())
         context = Context({
-            'db_name': settings.DATABASE_NAME,
-            'db_user': settings.DATABASE_USER,
-            'db_password': settings.DATABASE_PASSWORD
+            'db_name': settings.DATABASES['default']['NAME'],
+            'db_user': settings.DATABASES['default']['USER'],
+            'db_password': settings.DATABASES['default']['PASSWORD'],
         })
-        print tpl.render(context)
+        print(tpl.render(context))
