@@ -1,24 +1,24 @@
 from django.core.management.base import NoArgsCommand
-from django.db import transaction
 import os.path
 import askbot
 from askbot.search.postgresql import setup_full_text_search
 
 class Command(NoArgsCommand):
-    @transaction.commit_on_success
+
     def handle_noargs(self, **options):
+        dir_path = askbot.get_install_directory()
         script_path = os.path.join(
-                            askbot.get_install_directory(),
+                            dir_path,
                             'search',
                             'postgresql',
-                            'thread_and_post_models_10032013.plsql'
+                            'thread_and_post_models_03012016.plsql'
                         )
         setup_full_text_search(script_path)
 
         script_path = os.path.join(
-                            askbot.get_install_directory(),
+                            dir_path,
                             'search',
                             'postgresql',
-                            'user_profile_search_09262015.plsql'
+                            'user_profile_search_12202015.plsql'
                         )
         setup_full_text_search(script_path)
