@@ -1,3 +1,4 @@
+from __future__ import print_function
 import datetime
 from django.core.management.base import NoArgsCommand
 from django.conf import settings as django_settings
@@ -44,7 +45,7 @@ class Command(NoArgsCommand):
         #for all users, excluding blocked
         #for each user, select a tag filtered subset
         #format the email reminder and send it
-        for user in models.User.objects.exclude(askbot_profile__status = 'b'):
+        for user in models.User.objects.exclude(askbot_profile__status__in = ('t', 'c')):
             user_questions = questions.filter(author=user)
 
             final_question_list = user_questions.get_questions_needing_reminder(
@@ -65,7 +66,7 @@ class Command(NoArgsCommand):
                     })
 
             if DEBUG_THIS_COMMAND:
-                print "User: %s<br>\nSubject:%s<br>\nText: %s<br>\n" % \
-                    (user.email, email.render_subject(), email.render_body())
+                print("User: %s<br>\nSubject:%s<br>\nText: %s<br>\n" % \
+                    (user.email, email.render_subject(), email.render_body()))
             else:
                 email.send([user.email],)
