@@ -1,6 +1,8 @@
+from __future__ import print_function
 import askbot
 import datetime
 import traceback
+from collections import OrderedDict
 
 from django.conf import settings as django_settings
 from django.contrib.contenttypes.models import ContentType
@@ -8,7 +10,6 @@ from django.contrib.sites.models import Site
 from django.core.management.base import NoArgsCommand
 from django.db import connection
 from django.db.models import Q, F
-from django.utils.datastructures import SortedDict
 from django.utils import timezone
 from django.utils.translation import ugettext as _
 from django.utils.translation import activate as activate_language
@@ -93,7 +94,7 @@ class Command(NoArgsCommand):
     def handle_noargs(self, **options):
         if askbot_settings.ENABLE_EMAIL_ALERTS:
             activate_language(django_settings.LANGUAGE_CODE)
-            for user in User.objects.exclude(askbot_profile__status='b').iterator():
+            for user in User.objects.exclude(askbot_profile__status__in=('b', 't')).iterator():
                 try:
                     if email_is_blacklisted(user.email) \
                         and askbot_settings.BLACKLISTED_EMAIL_PATTERNS_MODE == 'strict':
@@ -104,7 +105,7 @@ class Command(NoArgsCommand):
             connection.close()
 
     def format_debug_msg(self, user, content):
-        msg = u"%s site_id=%d user=%s: %s" % ( 
+        msg = u"%s site_id=%d user=%s: %s" % (
             timezone.now().strftime('%y-%m-%d %h:%m:%s'),
             SITE_ID,
             repr(user.username),
@@ -115,7 +116,7 @@ class Command(NoArgsCommand):
     def report_exception(self, user):
         """reports exception that happened during sending email alert to user"""
         message = self.format_debug_msg(user, traceback.format_exc())
-        print message
+        print(message)
         admin_email = askbot_settings.ADMIN_EMAIL
         try:
             subject_line = u"Error processing daily/weekly notification for User '%s' for Site '%s'" % (user.username, SITE_ID)
@@ -126,10 +127,10 @@ class Command(NoArgsCommand):
             )
         except:
             message = u"ERROR: was unable to report this exception to %s: %s" % (admin_email, traceback.format_exc())
-            print self.format_debug_msg(user, message)
+            print(self.format_debug_msg(user, message))
         else:
             message = u"Sent email reporting this exception to %s" % admin_email
-            print self.format_debug_msg(user, message)
+            print(self.format_debug_msg(user, message))
 
     def get_updated_questions_for_user(self, user):
         """
@@ -138,6 +139,11 @@ class Command(NoArgsCommand):
         views
         """
 
+        old_content_cutoff_timestamp = max(
+            user.date_joined, #exclude old stuff
+            django_settings.ASKBOT_DELAYED_EMAIL_ALERTS_CUTOFF_TIMESTAMP
+        )
+
         user_feeds = EmailFeedSetting.objects.filter(
             subscriber=user
         ).exclude(frequency__in=('n', 'i'))
@@ -172,10 +178,11 @@ class Command(NoArgsCommand):
         #base question query set for this user
         #basic things - not deleted, not closed, not too old
         #not last edited by the same user
+
         base_qs = Post.objects.get_questions().exclude(
             thread__last_activity_by=user
         ).exclude(
-            thread__last_activity_at__lt=user.date_joined#exclude old stuff
+            thread__last_activity_at__lt=old_content_cutoff_timestamp
         ).exclude(
             deleted=True
         ).exclude(
@@ -259,7 +266,7 @@ class Command(NoArgsCommand):
                     q_all_B.cutoff_time = cutoff_time
 
         #build ordered list questions for the email report
-        q_list = SortedDict()
+        q_list = OrderedDict()
 
         #todo: refactor q_list into a separate class?
         extend_question_list(q_sel_A, q_list, languages=languages)
@@ -374,8 +381,8 @@ class Command(NoArgsCommand):
                 emailed_at = update_info.active_at
             except Activity.DoesNotExist:
                 update_info = Activity(
-                                    user=user, 
-                                    content_object=q, 
+                                    user=user,
+                                    content_object=q,
                                     activity_type=EMAIL_UPDATE_ACTIVITY
                                 )
                 emailed_at = datetime.datetime(1970, 1, 1)  #long time ago
@@ -439,7 +446,7 @@ class Command(NoArgsCommand):
             else:
                 meta_data['skip'] = False
                 #print 'not skipping'
-                update_info.active_at = timezone.now() 
+                update_info.active_at = timezone.now()
                 if DEBUG_THIS_COMMAND == False:
                     update_info.save() #save question email update activity
         #q_list is actually an ordered dictionary
@@ -494,7 +501,7 @@ class Command(NoArgsCommand):
                         'title': q.thread.title
                     })
 
-            activate_language(user.get_primary_language())
+            activate_language(user.primary_language)
             email = BatchEmailAlert({
                 'questions': questions_data,
                 'question_count': question_count,
