@@ -3,8 +3,8 @@ This module records the site visits by the authenticated users
 
 Included here is the ViewLogMiddleware
 """
-import datetime
 from askbot import signals
+from django.utils import timezone
 
 
 class ViewLogMiddleware(object):
@@ -16,6 +16,6 @@ class ViewLogMiddleware(object):
         #send the site_visited signal for the authenticated users
         if request.user.is_authenticated():
             signals.site_visited.send(None, #this signal has no sender
-                user = request.user,
-                timestamp = datetime.datetime.now()
+                user=request.user,
+                timestamp=timezone.now()
             )
