@@ -6,8 +6,7 @@ from askbot.conf import settings as askbot_settings
 from askbot.utils.markup import convert_text
 
 class BaseQuerySetManager(models.Manager):
-    """a base class that allows chainable qustom filters
-    on the query sets
+    """Base class for chainable custom filters on the query sets.
 
     pattern from http://djangosnippets.org/snippets/562/
 
@@ -23,7 +22,7 @@ class BaseQuerySetManager(models.Manager):
     >>>    #add more custom filters here
     >>>
     >>>class SomeManager(askbot.models.base.BaseQuerySetManager)
-    >>>    def get_query_set(self):
+    >>>    def get_queryset(self):
     >>>        return SomeQuerySet(self.model)
     >>>
     >>>class SomeModel(django.db.models.Model)
@@ -41,7 +40,7 @@ class BaseQuerySetManager(models.Manager):
         try:
             return getattr(self.__class__, attr, *args)
         except AttributeError:
-            return getattr(self.get_query_set(), attr, *args)
+            return getattr(self.get_queryset(), attr, *args)
 
 
 class AnonymousContent(models.Model):
