@@ -1,4 +1,5 @@
 import datetime
+
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.contenttypes import generic
 from django.contrib.auth.models import User
@@ -6,9 +7,13 @@ from django.db import models
 from django.utils.translation import ugettext as _
 from django.utils.html import escape
 from django.utils import timezone
-from askbot import const
 from django.core.urlresolvers import reverse
 
+from askbot import const
+from askbot.models.fields import LanguageCodeField
+from askbot.utils.translation import get_language
+
+
 class VoteManager(models.Manager):
     def get_up_vote_count_from_user(self, user):
         if user is not None:
@@ -25,7 +30,8 @@ class VoteManager(models.Manager):
     def get_votes_count_today_from_user(self, user):
         if user is not None:
             today = datetime.date.today()
-            return self.filter(user=user, voted_at__range=(today, today + datetime.timedelta(1))).count()
+            date_range = today, today + datetime.timedelta(1)
+            return self.filter(user=user, voted_at__range=date_range).count()
         else:
             return 0
 
@@ -40,8 +46,8 @@ class Vote(models.Model):
     user = models.ForeignKey('auth.User', related_name='askbot_votes')
     voted_post = models.ForeignKey('Post', related_name='votes')
 
-    vote           = models.SmallIntegerField(choices=VOTE_CHOICES)
-    voted_at       = models.DateTimeField(default=timezone.now)
+    vote = models.SmallIntegerField(choices=VOTE_CHOICES)
+    voted_at = models.DateTimeField(default=timezone.now)
 
     objects = VoteManager()
 
@@ -49,9 +55,11 @@ class Vote(models.Model):
         unique_together = ('user', 'voted_post')
         app_label = 'askbot'
         db_table = u'vote'
+        verbose_name = _("vote")
+        verbose_name_plural = _("votes")
 
     def __unicode__(self):
-        return u'[%s] voted at %s: %s' %(self.user, self.voted_at, self.vote)
+        return u'[%s] voted at %s: %s' % (self.user, self.voted_at, self.vote)
 
     def __int__(self):
         """1 if upvote -1 if downvote"""
@@ -74,7 +82,7 @@ class Vote(models.Model):
 
         return change in score on the post
         """
-        #importing locally because of circular dependency
+        # importing locally because of circular dependency
         from askbot import auth
         score_before = self.voted_post.points
         if self.vote > 0:
@@ -92,12 +100,11 @@ class BadgeData(models.Model):
     """Awarded for notable actions performed on the site by Users."""
     slug = models.SlugField(max_length=50, unique=True)
     awarded_count = models.PositiveIntegerField(default=0)
-    awarded_to = models.ManyToManyField(
-                    User, through='Award', related_name='badges'
-                )
-    #use this field if badges should be sorted
-    #on the badges page in some specific ordering
-    #and add setting ASKBOT_BADGE_ORDERING = 'custom'
+    awarded_to = models.ManyToManyField(User, through='Award',
+                                        related_name='badges')
+    # use this field if badges should be sorted
+    # on the badges page in some specific ordering
+    # and add setting ASKBOT_BADGE_ORDERING = 'custom'
     display_order = models.PositiveIntegerField(default=0)
 
     def _get_meta_data(self):
@@ -125,12 +132,14 @@ class BadgeData(models.Model):
         return self._get_meta_data().css_class
 
     def get_type_display(self):
-        #todo - rename "type" -> "level" in this model
+        # TODO: rename "type" -> "level" in this model
         return self._get_meta_data().get_level_display()
 
     class Meta:
         app_label = 'askbot'
         ordering = ('display_order', 'slug')
+        verbose_name = _("badge data")
+        verbose_name_plural = _("badge data")
 
     def __unicode__(self):
         return u'%s: %s' % (self.get_type_display(), self.slug)
@@ -138,40 +147,47 @@ class BadgeData(models.Model):
     def get_absolute_url(self):
         return '%s%s/' % (reverse('badge', args=[self.id]), self.slug)
 
+
 class Award(models.Model):
     """The awarding of a Badge to a User."""
-    user       = models.ForeignKey(User, related_name='award_user')
-    badge      = models.ForeignKey(BadgeData, related_name='award_badge')
-    content_type   = models.ForeignKey(ContentType)
-    object_id      = models.PositiveIntegerField()
+    user = models.ForeignKey(User, related_name='award_user')
+    badge = models.ForeignKey(BadgeData, related_name='award_badge')
+    content_type = models.ForeignKey(ContentType)
+    object_id = models.PositiveIntegerField()
     content_object = generic.GenericForeignKey('content_type', 'object_id')
     awarded_at = models.DateTimeField(default=timezone.now)
-    notified   = models.BooleanField(default=False)
+    notified = models.BooleanField(default=False)
 
     def __unicode__(self):
-        return u'[%s] is awarded a badge [%s] at %s' % (self.user.username, self.badge.get_name(), self.awarded_at)
+        return u'[%s] is awarded a badge [%s] at %s' % (self.user.username,
+                                                        self.badge.get_name(),
+                                                        self.awarded_at)
 
     class Meta:
         app_label = 'askbot'
         db_table = u'award'
+        verbose_name = _("award")
+        verbose_name_plural = _("awards")
+
 
 class ReputeManager(models.Manager):
     def get_reputation_by_upvoted_today(self, user):
         """
-        For one user in one day, he can only earn rep till certain score (ep. +200)
-        by upvoted(also subtracted from upvoted canceled). This is because we need
-        to prohibit gaming system by upvoting/cancel again and again.
+        For one user in one day, he can only earn rep till certain score
+        (ep. +200) by upvoted(also subtracted from upvoted canceled). This is
+        because we need to prohibit gaming system by upvoting/cancel again and
+        again.
         """
         if user is None:
             return 0
         else:
             today = datetime.date.today()
             tomorrow = today + datetime.timedelta(1)
-            rep_types = (1,-8)
+            rep_types = (1, -8)
             sums = self.filter(models.Q(reputation_type__in=rep_types),
-                                user=user,
-                                reputed_at__range=(today, tomorrow),
-                      ).aggregate(models.Sum('positive'), models.Sum('negative'))
+                               user=user,
+                               reputed_at__range=(today, tomorrow))\
+                .aggregate(models.Sum('positive'), models.Sum('negative'))
             if sums:
                 pos = sums['positive__sum']
                 neg = sums['negative__sum']
@@ -183,30 +199,42 @@ class ReputeManager(models.Manager):
             else:
                 return 0
 
+
 class Repute(models.Model):
     """The reputation histories for user"""
-    user     = models.ForeignKey(User)
-    #todo: combine positive and negative to one value
+    user = models.ForeignKey(User)
+    # TODO: combine positive and negative to one value
     positive = models.SmallIntegerField(default=0)
     negative = models.SmallIntegerField(default=0)
     question = models.ForeignKey('Post', null=True, blank=True)
+    language_code = LanguageCodeField()
     reputed_at = models.DateTimeField(default=timezone.now)
     reputation_type = models.SmallIntegerField(choices=const.TYPE_REPUTATION)
     reputation = models.IntegerField(default=1)
 
-    #comment that must be used if reputation_type == 10
-    #assigned_by_moderator - so that reason can be displayed
-    #in that case Question field will be blank
+    # comment that must be used if reputation_type == 10
+    # assigned_by_moderator - so that reason can be displayed
+    # in that case Question field will be blank
     comment = models.CharField(max_length=128, null=True)
 
     objects = ReputeManager()
 
     def __unicode__(self):
-        return u'[%s]\' reputation changed at %s' % (self.user.username, self.reputed_at)
+        return u'[%s]\' reputation changed at %s' % (self.user.username,
+                                                     self.reputed_at)
 
     class Meta:
         app_label = 'askbot'
         db_table = u'repute'
+        verbose_name = _("repute")
+        verbose_name_plural = _("repute")
+
+    def save(self, *args, **kwargs):
+        if self.question:
+            self.language_code = self.question.language_code
+        else:
+            self.language_code = get_language()
+        super(Repute, self).save(*args, **kwargs)
 
     def get_explanation_snippet(self):
         """returns HTML snippet with a link to related question
@@ -217,19 +245,18 @@ class Repute(models.Model):
 
         part of the purpose of this method is to hide this idiosyncracy
         """
-        if self.reputation_type == 10:#todo: hide magic number
-            return  _('<em>Changed by moderator. Reason:</em> %(reason)s') \
-                                                    % {'reason':self.comment}
-        else:
-            delta = self.positive + self.negative#.negative is < 0 so we add!
+        if self.reputation_type == 10:  # TODO: hide magic number
+            return _('<em>Changed by moderator. Reason:</em> %(reason)s') \
+                                                    % {'reason': self.comment}
+        else:  # .negative is < 0 so we add!
+            delta = self.positive + self.negative
             link_title_data = {
-                                'points': abs(delta),
-                                'username': self.user.username,
-                                'question_title': self.question.thread.title
-                            }
+                'points': abs(delta),
+                'username': self.user.username,
+                'question_title': self.question.thread.title
+            }
 
-            return '<a href="%(url)s">%(question_title)s</a>' \
-                            % {
-                               'url': self.question.get_absolute_url(),
-                               'question_title': escape(self.question.thread.title),
-                            }
+            return '<a href="%(url)s">%(question_title)s</a>' % {
+               'url': self.question.get_absolute_url(),
+               'question_title': escape(self.question.thread.title),
+            }
