@@ -30,6 +30,10 @@ def patch_django():
 
     if major == 1 and minor > 5:
         django_patches.add_hashcompat()
+        django_patches.add_simplejson()
+
+    if major == 1 and minor == 8:
+        django_patches.patch_django_template()
 
 def patch_coffin():
     """coffin before version 0.3.4
