@@ -294,7 +294,7 @@ def add_import_library_function():
         app_module = import_module(app_path)
         try:
             mod = import_module(taglib_module)
-        except ImportError, e:
+        except ImportError as e:
             # If the ImportError is because the taglib submodule does not exist, that's not
             # an error that should be raised. If the submodule exists and raised an ImportError
             # on the attempt to load it, that we want to raise.
@@ -366,6 +366,15 @@ def add_hashcompat():
     sys.modules['django.utils.hashcompat'] = hashcompat
 
 
+def add_simplejson():
+    """adds back simplejson - which may be used
+    by the dependency libraries"""
+    import django.utils
+    import simplejson
+    django.utils.simplejson = simplejson
+    sys.modules['django.utils.simplejson'] = simplejson
+
+
 from django.utils import six
 from django.utils.functional import Promise
 import django.utils.html
@@ -394,3 +403,19 @@ def wrap_escape(func):
     def wrapped(*args, **kwargs):
         return mark_safe(func(*args, **kwargs))
     return wrapped
+
+
+def patch_django_template():
+    import django.template
+    django.template.add_to_builtins = django.template.base.add_to_builtins
+    django.template.builtins = django.template.base.builtins
+    django.template.get_library = django.template.base.get_library
+    django.template.import_library = django.template.base.import_library
+    django.template.Origin = django.template.base.Origin
+    django.template.InvalidTemplateLibrary = django.template.base.InvalidTemplateLibrary
+
+    from django.template.loaders import app_directories
+    app_directories.app_template_dirs = list() #dummy value
+    # from django.template.utils import get_app_template_dirs
+    # later must be set to get_app_template_dirs('templates')
+
