@@ -73,16 +73,23 @@ ADMIN_MEDIA_PREFIX = STATIC_URL + 'admin/'#must be this value
 SECRET_KEY = 'sdljdfjkldsflsdjkhsjkldgjlsdgfs s '
 
 # List of callables that know how to import templates from various sources.
-TEMPLATE_LOADERS = (
-    'django.template.loaders.filesystem.Loader',
-    'django.template.loaders.app_directories.Loader',
-    #below is askbot stuff for this tuple
-    #'askbot.skins.loaders.load_template_source', #changed due to bug 97
-    'askbot.skins.loaders.filesystem_load_template_source',
-    #'django.template.loaders.eggs.load_template_source',
+TEMPLATES = (
+    {
+        'BACKEND': 'askbot.skins.template_backends.AskbotSkinTemplates',
+    },
+    {
+        'BACKEND': 'django.template.backends.django.DjangoTemplates',
+        'DIRS': [],
+        'APP_DIRS': True,
+        'OPTIONS': {
+            'context_processors': [
+                'django.core.context_processors.request',
+                'django.contrib.auth.context_processors.auth',
+            ]
+        }
+    },
 )
 
-
 MIDDLEWARE_CLASSES = (
     #'django.middleware.gzip.GZipMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
@@ -119,19 +126,7 @@ COMPRESS_PRECOMPILERS = (
 ROOT_URLCONF = os.path.basename(os.path.dirname(__file__)) + '.urls'
 
 
-TEMPLATE_CONTEXT_PROCESSORS = (
-    'django.core.context_processors.request',
-    'askbot.context.application_settings',
-    #'django.core.context_processors.i18n',
-    'askbot.user_messages.context_processors.user_messages',#must be before auth
-    'django.contrib.auth.context_processors.auth', #this is required for admin
-    'django.core.context_processors.csrf', #necessary for csrf protection
-    'askbot.deps.group_messaging.context.group_messaging_context',
-)
-
-
 INSTALLED_APPS = (
-    'longerusername',
     'django.contrib.auth',
     'django.contrib.contenttypes',
     'django.contrib.sessions',
@@ -149,7 +144,6 @@ INSTALLED_APPS = (
     'askbot',
     'askbot.deps.django_authopenid',
     #'askbot.importers.stackexchange', #se loader
-    'south',
     'askbot.deps.livesettings',
     'keyedcache',
     'robots',
@@ -254,13 +248,7 @@ COMPRESS_JS_FILTERS = []
 COMPRESS_PARSER = 'compressor.parser.HtmlParser'
 JINJA2_EXTENSIONS = ('compressor.contrib.jinja2ext.CompressorExtension',)
 
-# Use syncdb for tests instead of South migrations. Without this, some tests
-# fail spuriously in MySQL.
-SOUTH_TESTS_MIGRATE = False
-
 VERIFIER_EXPIRE_DAYS = 3
 AVATAR_AUTO_GENERATE_SIZES = (16, 32, 48, 128)
 
-# compatibility with django1.5
-TEST_RUNNER = 'django.test.simple.DjangoTestSuiteRunner'
 SESSION_SERIALIZER = 'django.contrib.sessions.serializers.PickleSerializer'
