@@ -7,6 +7,7 @@ question: why not run these from askbot/__init__.py?
 
 the main function is run_startup_tests
 """
+from __future__ import print_function
 from askbot.conf.static_settings import settings as django_settings
 import askbot
 import django
@@ -15,14 +16,14 @@ import pkg_resources
 import re
 import sys
 import urllib
+from urlparse import urlparse
 from django.db import connection
 from django.core.cache import cache
 from django.core.exceptions import ImproperlyConfigured
-from django.utils import timezone
+from django.utils import timezone, six
 from askbot.utils.loading import load_module
 from askbot.utils.functions import enumerate_string_list
 from askbot.utils.url_utils import urls_equal
-from urlparse import urlparse
 
 PREAMBLE = """\n
 ************************
@@ -37,6 +38,7 @@ If necessary, type ^C (Ctrl-C) to stop the program
 (to disable the self-test add ASKBOT_SELF_TEST = False).
 """
 
+
 class AskbotConfigError(ImproperlyConfigured):
     """Prints an error with a preamble and possibly a footer"""
     def __init__(self, error_message):
@@ -46,6 +48,7 @@ class AskbotConfigError(ImproperlyConfigured):
             msg += FOOTER
             super(AskbotConfigError, self).__init__(msg)
 
+
 def domain_is_bad():
     from askbot.conf import settings as askbot_settings
     parsed = urlparse(askbot_settings.APP_URL)
@@ -55,24 +58,27 @@ def domain_is_bad():
         return True
     return False
 
+
 def askbot_warning(line):
     """prints a warning with the nice header, but does not quit"""
-    print >> sys.stderr, unicode(line).encode('utf-8')
+    print(unicode(line).encode('utf-8'), file=sys.stderr)
 
-def print_errors(error_messages, header = None, footer = None):
+
+def print_errors(error_messages, header=None, footer=None):
     """if there is one or more error messages,
     raise ``class:AskbotConfigError`` with the human readable
     contents of the message
     * ``header`` - text to show above messages
     * ``footer`` - text to show below messages
     """
-    if len(error_messages) == 0:
+    if not error_messages:
         return
     if len(error_messages) > 1:
         error_messages = enumerate_string_list(error_messages)
 
     message = ''
-    if header: message += header + '\n'
+    if header:
+        message += header + '\n'
     message += 'Please attend to the following:\n\n'
     message += '\n\n'.join(error_messages)
     if footer:
@@ -80,14 +86,14 @@ def print_errors(error_messages, header = None, footer = None):
 
     raise AskbotConfigError(message)
 
+
 def format_as_text_tuple_entries(items):
     """prints out as entries or tuple containing strings
     ready for copy-pasting into say django settings file"""
     return "    '%s'," % "',\n    '".join(items)
 
-#todo:
-#
-# *validate emails in settings.py
+
+# TODO: *validate emails in settings.py
 def test_askbot_url():
     """Tests the ASKBOT_URL setting for the
     well-formedness and raises the :class:`AskbotConfigError`
@@ -96,14 +102,12 @@ def test_askbot_url():
     url = django_settings.ASKBOT_URL
     if url != '':
 
-        if isinstance(url, str) or isinstance(url, unicode):
-            pass
-        else:
+        if not isinstance(url, six.string_types):
             msg = 'setting ASKBOT_URL must be of string or unicode type'
             raise AskbotConfigError(msg)
 
         if url == '/':
-            msg = 'value "/" for ASKBOT_URL is invalid. '+ \
+            msg = 'value "/" for ASKBOT_URL is invalid. ' + \
                 'Please, either make ASKBOT_URL an empty string ' + \
                 'or a non-empty path, ending with "/" but not ' + \
                 'starting with "/", for example: "forum/"'
@@ -153,19 +157,19 @@ def test_middleware():
         'askbot.middleware.anon_user.ConnectToSessionMessagesMiddleware',
         'askbot.middleware.forum_mode.ForumModeMiddleware',
         'askbot.middleware.cancel.CancelActionMiddleware',
-        'django.middleware.transaction.TransactionMiddleware',
+        #'django.middleware.transaction.TransactionMiddleware',
     ]
-    if 'debug_toolbar' in django_settings.INSTALLED_APPS:
-        required_middleware.append(
-            'debug_toolbar.middleware.DebugToolbarMiddleware',
-        )
+    #if 'debug_toolbar' in django_settings.INSTALLED_APPS:
+    #    required_middleware.append(
+    #        'debug_toolbar.middleware.DebugToolbarMiddleware',
+    #    )
     required_middleware.extend([
         'askbot.middleware.view_log.ViewLogMiddleware',
         'askbot.middleware.spaceless.SpacelessMiddleware',
         'askbot.middleware.csrf.CsrfViewMiddleware'
     ])
     found_middleware = [x for x in django_settings.MIDDLEWARE_CLASSES
-                            if x in required_middleware]
+                        if x in required_middleware]
     if found_middleware != required_middleware:
         # either middleware is out of order or it's missing an item
         missing_middleware_set = set(required_middleware) - set(found_middleware)
@@ -185,13 +189,13 @@ for the correct order.\n\n"""
         raise AskbotConfigError(error_message + middleware_text)
 
 
-    #middleware that was used in the past an now removed
+    # middleware that was used in the past an now removed
     canceled_middleware = [
         'askbot.deps.recaptcha_django.middleware.ReCaptchaMiddleware'
     ]
 
     invalid_middleware = [x for x in canceled_middleware
-                            if x in django_settings.MIDDLEWARE_CLASSES]
+                          if x in django_settings.MIDDLEWARE_CLASSES]
     if invalid_middleware:
         error_message = """\n\nPlease remove the following middleware entries from
 the list of MIDDLEWARE_CLASSES in your settings.py - these are not used any more:\n\n"""
@@ -204,7 +208,7 @@ def try_import(module_name, pypi_package_name, show_requirements_message=True,
     A corresponding Python package in the case import fails"""
     try:
         load_module(module_name)
-    except ImportError, error:
+    except ImportError as error:
         message = 'Error: ' + unicode(error)
         message += '\n\nPlease run: >pip install %s' % pypi_package_name
         if show_requirements_message:
@@ -220,7 +224,7 @@ def unparse_requirement(req):
     line = req.name
     if req.specs:
         specs = ['%s%s' % spec for spec in req.specs]
-        line += ','.join(specs) 
+        line += ','.join(specs)
     if req.extras:
         line += ' [%s]' % ','.join(req.extras)
     return line
@@ -285,14 +289,15 @@ def get_req_name_from_spec(spec):
 
 def find_mod_name(req_name):
     from askbot import REQUIREMENTS
-    req2mod = dict([(get_req_name_from_spec(v), k) for (k, v) in REQUIREMENTS.items()])
+    req2mod = dict([(get_req_name_from_spec(v), k)
+                    for (k, v) in REQUIREMENTS.items()])
     return req2mod[req_name]
 
 
 def test_modules():
     """tests presence of required modules"""
     from askbot import REQUIREMENTS
-    #flatten requirements into file-like string
+    # flatten requirements into file-like string
     req_text = '\n'.join(REQUIREMENTS.values())
     import requirements
     parsed_requirements = requirements.parse(req_text)
@@ -310,47 +315,17 @@ def test_postgres():
         version = psycopg2.__version__.split(' ')[0].split('.')
         if version == ['2', '4', '2']:
             raise AskbotConfigError(
-                'Please install psycopg2 version 2.4.1,\n version 2.4.2 has a bug'
-            )
+                'Please install psycopg2 version 2.4.1,\n version 2.4.2 has a bug')
         elif version > ['2', '4', '2']:
-            pass #don't know what to do
+            pass  # don't know what to do
         else:
-            pass #everythin is ok
+            pass  # everythin is ok
 
-def test_template_loader():
+
+def test_template_settings():
     """Sends a warning if you have an old style template
     loader that used to send a warning"""
-    old_loaders = (
-        'askbot.skins.loaders.load_template_source',
-        'askbot.skins.loaders.filesystem_load_template_source',
-    )
     errors = list()
-    for loader in old_loaders:
-        if loader in django_settings.TEMPLATE_LOADERS:
-            errors.append(
-                'remove "%s" from the TEMPLATE_LOADERS setting' % loader
-            )
-
-    current_loader = 'askbot.skins.loaders.Loader'
-    if current_loader not in django_settings.TEMPLATE_LOADERS:
-        errors.append(
-            'add "%s", to the beginning of the TEMPLATE_LOADERS' % current_loader
-        )
-    elif django_settings.TEMPLATE_LOADERS[0] != current_loader:
-        errors.append(
-            '"%s", must be the first element of TEMPLATE_LOADERS' % current_loader
-        ) 
-
-    app_dir_loader = 'askbot.skins.loaders.JinjaAppDirectoryLoader'
-    if app_dir_loader not in django_settings.TEMPLATE_LOADERS:
-        errors.append(
-            'add "%s", as second item of the TEMPLATE_LOADERS' % app_dir_loader
-        )
-    elif django_settings.TEMPLATE_LOADERS.index(app_dir_loader) != 1:
-        errors.append(
-            'move "%s", to the second place in the TEMPLATE_LOADERS' % app_dir_loader
-        )
-
     try:
         jinja2_apps = getattr(django_settings, 'JINJA2_TEMPLATES')
     except AttributeError:
@@ -358,10 +333,9 @@ def test_template_loader():
     else:
         if 'captcha' not in jinja2_apps:
             errors.append("add to JINJA2_TEMPLATES in settings.py\n    'captcha',")
-
-
     print_errors(errors)
 
+
 def test_celery():
     """Tests celery settings
     todo: we are testing two things here
@@ -372,14 +346,14 @@ def test_celery():
     broker_transport = getattr(django_settings, 'BROKER_TRANSPORT', None)
     delay_time = getattr(django_settings, 'NOTIFICATION_DELAY_TIME', None)
     delay_setting_info = 'The delay is in seconds - used to throttle ' + \
-                    'instant notifications note that this delay will work only if ' + \
-                    'celery daemon is running Please search about ' + \
-                    '"celery daemon setup" for details'
+        'instant notifications note that this delay will work only if ' + \
+        'celery daemon is running Please search about ' + \
+        '"celery daemon setup" for details'
 
     if delay_time is None:
         raise AskbotConfigError(
-            '\nPlease add to your settings.py\n' + \
-            'NOTIFICATION_DELAY_TIME = 60*15\n' + \
+            '\nPlease add to your settings.py\n' +
+            'NOTIFICATION_DELAY_TIME = 60*15\n' +
             delay_setting_info
         )
     elif not isinstance(delay_time, int):
@@ -411,12 +385,13 @@ def test_celery():
             "in your settings.py file"
         )
 
+
 def test_compressor():
     """test settings for django compressor"""
     errors = list()
 
     js_filters = getattr(django_settings, 'COMPRESS_JS_FILTERS', [])
-    if len(js_filters) > 0:
+    if js_filters:
         errors.append(
             'Askbot does not yet support js minification, please add to your settings.py:\n'
             'COMPRESS_JS_FILTERS = []'
@@ -427,24 +402,25 @@ def test_compressor():
             'add to the INSTALLED_APPS the following entry:\n'
             "    'compressor',"
         )
-
     print_errors(errors)
 
+
 def test_media_url():
     """makes sure that setting `MEDIA_URL`
     has leading slash"""
     media_url = django_settings.MEDIA_URL
-    #todo: add proper url validation to MEDIA_URL setting
+    # TODO: add proper url validation to MEDIA_URL setting
     if not (media_url.startswith('/') or media_url.startswith('http')):
         raise AskbotConfigError(
             "\nMEDIA_URL parameter must be a unique url on the site\n"
             "and must start with a slash - e.g. /media/ or http(s)://"
         )
 
+
 class SettingsTester(object):
     """class to test contents of the settings.py file"""
 
-    def __init__(self, requirements = None):
+    def __init__(self, requirements=None):
         """loads the settings module and inits some variables
         parameter `requirements` is a dictionary with keys
         as setting names and values - another dictionary, which
@@ -458,12 +434,8 @@ class SettingsTester(object):
         self.messages = list()
         self.requirements = requirements
 
-
-    def test_setting(self, name,
-            value = None, message = None,
-            test_for_absence = False,
-            replace_hint = None
-        ):
+    def test_setting(self, name, value=None, message=None,
+                     test_for_absence=False, replace_hint=None):
         """if setting does is not present or if the value != required_value,
         adds an error message
         """
@@ -481,11 +453,8 @@ class SettingsTester(object):
 
     def run(self):
         for setting_name in self.requirements:
-            self.test_setting(
-                setting_name,
-                **self.requirements[setting_name]
-            )
-        if len(self.messages) != 0:
+            self.test_setting(setting_name, **self.requirements[setting_name])
+        if self.messages:
             raise AskbotConfigError(
                 '\n\nTime to do some maintenance of your settings.py:\n\n* ' +
                 '\n\n* '.join(self.messages)
@@ -506,6 +475,7 @@ def test_new_skins():
                 'Now we have `askbot/templates` and `askbot/media`') % item_path
             )
 
+
 def test_staticfiles():
     """tests configuration of the staticfiles app"""
     errors = list()
@@ -550,7 +520,7 @@ def test_staticfiles():
         )
     url = urlparse(static_url).path
     if not (url.startswith('/') and url.endswith('/')):
-        #a simple check for the url
+        # a simple check for the url
         errors.append(
             'Path in the STATIC_URL must start and end with the /.'
         )
@@ -605,8 +575,8 @@ def test_staticfiles():
     if django_settings.STATICFILES_STORAGE == \
         'django.contrib.staticfiles.storage.StaticFilesStorage':
         if os.path.dirname(django_settings.STATIC_ROOT) == '':
-            #static root is needed only for local storoge of
-            #the static files
+            # static root is needed only for local storoge of
+            # the static files
             raise AskbotConfigError(
                 'Specify the static files directory '
                 'with setting STATIC_ROOT'
@@ -633,7 +603,7 @@ def test_staticfiles():
 
     if missing_finders:
         errors.append(
-            'Please make sure that the following items are \n' + \
+            'Please make sure that the following items are \n' +
             'part of the STATICFILES_FINDERS tuple, create this tuple, if it is missing:\n' +
             '    "' + '",\n    "'.join(missing_finders) + '",\n'
         )
@@ -649,9 +619,10 @@ def test_staticfiles():
 
             )
 
+
 def test_csrf_cookie_domain():
     """makes sure that csrf cookie domain setting is acceptable"""
-    #todo: maybe use the same steps to clean domain name
+    # TODO: maybe use the same steps to clean domain name
     csrf_cookie_domain = django_settings.CSRF_COOKIE_DOMAIN
     if csrf_cookie_domain is None or str(csrf_cookie_domain.strip()) == '':
         raise AskbotConfigError(
@@ -661,8 +632,7 @@ def test_csrf_cookie_domain():
             'without the http(s):// prefix and without the port number.\n'
             'Examples: \n'
             "    CSRF_COOKIE_DOMAIN = '127.0.0.1'\n"
-            "    CSRF_COOKIE_DOMAIN = 'example.com'\n"
-        )
+            "    CSRF_COOKIE_DOMAIN = 'example.com'\n")
     if csrf_cookie_domain == 'localhost':
         raise AskbotConfigError(
             'Please do not use value "localhost" for the setting '
@@ -670,8 +640,7 @@ def test_csrf_cookie_domain():
             'instead use 127.0.0.1, a real IP '
             'address or domain name.'
             '\nThe value must match the network location you type in the '
-            'web browser to reach your site.'
-        )
+            'web browser to reach your site.')
     if re.match(r'https?://', csrf_cookie_domain):
         raise AskbotConfigError(
             'please remove http(s):// prefix in the CSRF_COOKIE_DOMAIN '
@@ -680,22 +649,20 @@ def test_csrf_cookie_domain():
     if ':' in csrf_cookie_domain:
         raise AskbotConfigError(
             'Please do not use port number in the CSRF_COOKIE_DOMAIN '
-            'setting'
-        )
+            'setting')
+
 
 def test_settings_for_test_runner():
     """makes sure that debug toolbar is disabled when running tests"""
     errors = list()
     if 'debug_toolbar' in django_settings.INSTALLED_APPS:
         errors.append(
-            'When testing - remove debug_toolbar from INSTALLED_APPS'
-        )
+            'When testing - remove debug_toolbar from INSTALLED_APPS')
     if 'debug_toolbar.middleware.DebugToolbarMiddleware' in \
         django_settings.MIDDLEWARE_CLASSES:
         errors.append(
             'When testing - remove debug_toolbar.middleware.DebugToolbarMiddleware '
-            'from MIDDLEWARE_CLASSES'
-        )
+            'from MIDDLEWARE_CLASSES')
     print_errors(errors)
 
 
@@ -705,6 +672,7 @@ def test_avatar():
     if 'avatar' in django_settings.INSTALLED_APPS:
         try_import('avatar', 'django-avatar', show_requirements_message=False)
 
+
 def test_haystack():
     if 'haystack' in django_settings.INSTALLED_APPS:
         try_import('haystack', 'django-haystack', show_requirements_message=False)
@@ -735,12 +703,13 @@ def test_haystack():
             footer = 'Please refer to haystack documentation at https://django-haystack.readthedocs.org/en/latest/settings.html'
             print_errors(errors, footer=footer)
 
+
 def test_custom_user_profile_tab():
     setting_name = 'ASKBOT_CUSTOM_USER_PROFILE_TAB'
     tab_settings = getattr(django_settings, setting_name)
     if tab_settings:
         if not isinstance(tab_settings, dict):
-            print "Setting %s must be a dictionary!!!" % setting_name
+            print("Setting %s must be a dictionary!!!" % setting_name)
 
         name = tab_settings.get('NAME', None)
         slug = tab_settings.get('SLUG', None)
@@ -754,8 +723,7 @@ def test_custom_user_profile_tab():
 
         if urllib.quote_plus(slug) != slug:
             errors.append(
-                "%s['SLUG'] must be url safe, make it simple" % setting_name
-            )
+                "%s['SLUG'] must be url safe, make it simple" % setting_name)
 
         try:
             func = load_module(func_name)
@@ -763,20 +731,21 @@ def test_custom_user_profile_tab():
             errors.append("%s['CONTENT_GENERATOR'] must be a dotted path to a function" % setting_name)
         header = 'Custom user profile tab is configured incorrectly in your settings.py file'
         footer = 'Please carefully read about adding a custom user profile tab.'
-        print_errors(errors, header = header, footer = footer)
+        print_errors(errors, header=header, footer=footer)
+
 
 def get_tinymce_sample_config():
     """returns the sample configuration for TinyMCE
     as string"""
     askbot_root = askbot.get_install_directory()
     file_path = os.path.join(
-                    askbot_root, 'setup_templates', 'tinymce_sample_config.py'
-                )
+        askbot_root, 'setup_templates', 'tinymce_sample_config.py')
     config_file = open(file_path, 'r')
     sample_config = config_file.read()
     config_file.close()
     return sample_config
 
+
 def test_tinymce():
     """tests the tinymce editor setup"""
     errors = list()
@@ -797,33 +766,32 @@ def test_tinymce():
     if missing_attrs:
         errors.append('add missing settings: %s' % ', '.join(missing_attrs))
 
-    #check compressor setting
+    # check compressor setting
     compressor_on = getattr(django_settings, 'TINYMCE_COMPRESSOR', False)
     if compressor_on is False:
         errors.append('add line: TINYMCE_COMPRESSOR = True')
-        #todo: add pointer to instructions on how to debug tinymce:
-        #1) add ('tiny_mce', os.path.join(ASKBOT_ROOT, 'media/js/tinymce')),
-        #   to STATIFILES_DIRS
-        #2) add this to the main urlconf:
-        #    (
-        #        r'^m/(?P<path>.*)$',
-        #        'django.views.static.serve',
-        #        {'document_root': static_root}
-        #    ),
-        #3) set `TINYMCE_COMPRESSOR = False`
-        #4) set DEBUG = False
-        #then - tinymce compressing will be disabled and it will
-        #be possible to debug custom tinymce plugins that are used with askbot
-
+        # TODO: add pointer to instructions on how to debug tinymce:
+        # 1) add ('tiny_mce', os.path.join(ASKBOT_ROOT, 'media/js/tinymce')),
+        #    to STATIFILES_DIRS
+        # 2) add this to the main urlconf:
+        #     (
+        #         r'^m/(?P<path>.*)$',
+        #         'django.views.static.serve',
+        #         {'document_root': static_root}
+        #     ),
+        # 3) set `TINYMCE_COMPRESSOR = False`
+        # 4) set DEBUG = False
+        # then - tinymce compressing will be disabled and it will
+        # be possible to debug custom tinymce plugins that are used with askbot
 
     config = getattr(django_settings, 'TINYMCE_DEFAULT_CONFIG', None)
     if config:
         if 'editor_deselector' not in config:
             message = "add to TINYMCE_DEFAULT_CONFIG\n'editor_deselector': 'mceNoEditor',"
             errors.append(message)
-        
+
         if 'convert_urls' in config:
-            if config['convert_urls'] is not False:
+            if config['convert_urls']:
                 message = "set 'convert_urls':False in TINYMCE_DEFAULT_CONFIG"
                 errors.append(message)
         else:
@@ -831,8 +799,8 @@ def test_tinymce():
             errors.append(message)
 
 
-    #check js root setting - before version 0.7.44 we used to have
-    #"common" skin and after we combined it into the default
+    # check js root setting - before version 0.7.44 we used to have
+    # "common" skin and after we combined it into the default
     js_root = getattr(django_settings, 'TINYMCE_JS_ROOT', '')
     relative_js_path = 'default/media/tinymce/'
     expected_js_root = os.path.join(django_settings.STATIC_ROOT, relative_js_path)
@@ -847,14 +815,14 @@ def test_tinymce():
                 'as template:\n\n' + get_tinymce_sample_config()
         print_errors(errors, header=header, footer=footer)
 
+
 def test_longerusername():
     """tests proper installation of the "longerusername" app
     """
     errors = list()
     if 'longerusername' not in django_settings.INSTALLED_APPS:
         errors.append(
-            "add 'longerusername', as the first item in the INSTALLED_APPS"
-        )
+            "add 'longerusername', as the first item in the INSTALLED_APPS")
     else:
         index = django_settings.INSTALLED_APPS.index('longerusername')
         if index != 0:
@@ -865,52 +833,10 @@ def test_longerusername():
         errors.append('run "python manage.py migrate longerusername"')
         print_errors(errors)
 
-def test_template_context_processors():
-    """makes sure that all necessary template context processors
-    are in the settings.py"""
-
-    required_processors = [
-        'django.core.context_processors.request',
-        'askbot.context.application_settings',
-        'askbot.user_messages.context_processors.user_messages',
-        'django.core.context_processors.csrf',
-        'askbot.deps.group_messaging.context.group_messaging_context',
-    ]
-    old_auth_processor = 'django.core.context_processors.auth'
-    new_auth_processor = 'django.contrib.auth.context_processors.auth'
-
-    invalid_processors = list()
-    if django.VERSION[1] <= 3:
-        required_processors.append(old_auth_processor)
-        if new_auth_processor in django_settings.TEMPLATE_CONTEXT_PROCESSORS:
-            invalid_processors.append(new_auth_processor)
-    elif django.VERSION[1] > 3:
-        required_processors.append(new_auth_processor)
-        if old_auth_processor in django_settings.TEMPLATE_CONTEXT_PROCESSORS:
-            invalid_processors.append(old_auth_processor)
-
-    missing_processors = list()
-    for processor in required_processors:
-        if processor not in django_settings.TEMPLATE_CONTEXT_PROCESSORS:
-            missing_processors.append(processor)
-
-    errors = list()
-    if invalid_processors:
-        message = 'remove from TEMPLATE_CONTEXT_PROCESSORS in settings.py:\n'
-        message += format_as_text_tuple_entries(invalid_processors)
-        errors.append(message)
-
-    if missing_processors:
-        message = 'add to TEMPLATE_CONTEXT_PROCESSORS in settings.py:\n'
-        message += format_as_text_tuple_entries(missing_processors)
-        errors.append(message)
-
-    print_errors(errors)
-
 
 def test_cache_backend():
     """prints a warning if cache backend is disabled or per-process"""
-    #test that cache actually works
+    # test that cache actually works
     errors = list()
 
     test_value = 'test value %s' % timezone.now()
@@ -919,11 +845,10 @@ def test_cache_backend():
         errors.append(
             'Cache server is unavailable.\n'
             'Check your CACHE... settings and make sure that '
-            'the cache backend is working properly.'
-        )
+            'the cache backend is working properly.')
     print_errors(errors)
 
-    #test the cache backend settings
+    # test the cache backend settings
     if django.VERSION[1] > 2:
         backend = django_settings.CACHES['default']['BACKEND']
     else:
@@ -950,8 +875,11 @@ see outdated content on your site.
 def test_group_messaging():
     """tests correctness of the "group_messaging" app configuration"""
     errors = list()
-    if 'group_messaging' not in django_settings.INSTALLED_APPS:
-        errors.append("add to the INSTALLED_APPS:\n'group_messaging'")
+    if 'askbot.deps.group_messaging' not in django_settings.INSTALLED_APPS:
+        errors.append("add to the INSTALLED_APPS:\n'askbot.deps.group_messaging',")
+
+    if 'group_messaging' in django_settings.INSTALLED_APPS:
+        errors.append("remove from the INSTALLED_APPS:\n'group_messaging',")
 
     settings_sample = ("GROUP_MESSAGING = {\n"
     "    'BASE_URL_GETTER_FUNCTION': 'askbot.models.user_get_profile_url',\n"
@@ -962,14 +890,12 @@ def test_group_messaging():
     if settings:
         url_params = settings.get('BASE_URL_PARAMS', {})
         have_wrong_params = not (
-                        url_params.get('section', None) == 'messages' and \
-                        url_params.get('sort', None) == 'inbox'
-                    )
+            url_params.get('section', None) == 'messages' and
+            url_params.get('sort', None) == 'inbox')
         url_getter = settings.get('BASE_URL_GETTER_FUNCTION', None)
         if url_getter != 'askbot.models.user_get_profile_url' or have_wrong_params:
             errors.append(
-                "make setting 'GROUP_MESSAGING to be exactly:\n" + settings_sample
-            )
+                "make setting 'GROUP_MESSAGING to be exactly:\n" + settings_sample)
 
         url_params = settings.get('BASE_URL_PARAMS', None)
     else:
@@ -982,12 +908,13 @@ def test_group_messaging():
 def test_secret_key():
     key = django_settings.SECRET_KEY
     if key.strip() == '':
-        print_errors(['please create a random SECRET_KEY setting',])
+        print_errors(['please create a random SECRET_KEY setting'])
     elif key == 'sdljdfjkldsflsdjkhsjkldgjlsdgfs s ':
         print_errors([
             'Please change your SECRET_KEY setting, the current is not secure'
         ])
 
+
 def test_locale_middlewares():
     django_locale_middleware = 'django.middleware.locale.LocaleMiddleware'
     askbot_locale_middleware = 'askbot.middleware.locale.LocaleMiddleware'
@@ -1012,7 +939,7 @@ def test_recaptcha():
     except AttributeError:
         errors.append('Please add to settings.py:\nNOCAPTCHA = True')
     else:
-        if nocaptcha != True:
+        if not nocaptcha:
             errors.append('Please modify settings.py with:\nNOCAPTCHA = True')
     print_errors(errors)
 
@@ -1020,15 +947,14 @@ def test_recaptcha():
 def test_lang_mode():
     legacy_multilang = getattr(django_settings, 'ASKBOT_MULTILINGUAL', None)
     errors = list()
-    if legacy_multilang == True:
-        errors.append("""replace ASKBOT_MULTILINGUAL = True with either:
-ASKBOT_LANGUAGE_MODE = 'url-lang' or 
+    if legacy_multilang is not None:
+        if legacy_multilang:
+            errors.append("""replace ASKBOT_MULTILINGUAL = True with either:
+ASKBOT_LANGUAGE_MODE = 'url-lang' or
 ASKBOT_LANGUAGE_MODE = 'user-lang'""")
-    if legacy_multilang == False:
-        errors.append("""replace ASKBOT_MULTILINGUAL = True with either:
+        else:
+            errors.append("""replace ASKBOT_MULTILINGUAL = True with either:
 ASKBOT_LANGUAGE_MODE = 'single-lang' or just delete the setting""")
-
-    if legacy_multilang in (True, False):
         print_errors(errors)
 
     mode = django_settings.ASKBOT_LANGUAGE_MODE
@@ -1053,11 +979,13 @@ ASKBOT_LANGUAGE_MODE = 'single-lang' or just delete the setting""")
 
     print_errors(errors)
 
+
 def test_messages_framework():
-    if not 'django.contrib.messages' in django_settings.INSTALLED_APPS:
+    if 'django.contrib.messages' not in django_settings.INSTALLED_APPS:
         errors = ('Add to the INSTALLED_APPS section of your settings.py:\n "django.contrib.messages"', )
         print_errors(errors)
 
+
 def test_service_url_prefix():
     errors = list()
     prefix = django_settings.ASKBOT_SERVICE_URL_PREFIX
@@ -1066,38 +994,35 @@ def test_service_url_prefix():
         if len(prefix) == 1 or (not prefix.endswith('/')):
             print_errors((message,))
 
+
 def test_versions():
     """inform of version incompatibilities, where possible"""
     errors = list()
     py_ver = sys.version_info
-    #python3 will not work
+    # python3 will not work
     if py_ver[0] == 3:
         errors.append(
             'Askbot does not yet support Python3, please use '
-            'the latest release of Python 2.x'
-        )
+            'the latest release of Python 2.x')
 
-    upgrade_msg = 'About upgrades, please read http://askbot.org/doc/upgrade.html'
     dj_ver = django.VERSION
-    if dj_ver[:2] >= (1, 7):
+    upgrade_msg = 'About upgrades, please read http://askbot.org/doc/upgrade.html'
+    if dj_ver < (1, 7) or dj_ver >= (1, 9):
+        errors.append('This version of Askbot supports only django 1.7 and 1.8 ' + upgrade_msg)
+    elif py_ver[:3] < (2, 7, 0):
         errors.append(
-            'Highest major version of django supported is 1.6. ' +
-            upgrade_msg
-        )
-    elif dj_ver[0:2] in ((1, 5), (1,6)) and py_ver[:3] < (2, 6, 5):
-        errors.append(
-            'Django 1.5 and 1.6 higher require Python '
-            'version 2.6.5 or higher, please see release notes.\n'
-            'https://docs.djangoproject.com/en/dev/releases/1.6/'
-        )
+            'Django 1.7 and higher requires Python 2.7'
+            'please see the release notes.\n'
+            'https://docs.djangoproject.com/en/dev/releases/1.7/')
 
     print_errors(errors)
 
+
 def run_startup_tests():
     """function that runs
     all startup tests, mainly checking settings config so far
     """
-    #this is first because it gives good info on what to install
+    # this is first because it gives good info on what to install
     try_import('requirements', 'requirements-parser')
     test_modules()
 
@@ -1108,7 +1033,7 @@ and for making posts by email"""
             show_requirements_message=False,
             extra_message=extra_message)
 
-    #todo: refactor this when another test arrives
+    # TODO: refactor this when another test arrives
     test_versions()
     test_lang_mode()
     test_askbot_url()
@@ -1120,7 +1045,7 @@ and for making posts by email"""
     test_group_messaging()
     test_haystack()
     test_jinja2()
-    test_longerusername()
+    #test_longerusername()
     test_new_skins()
     test_media_url()
     #test_postgres()
@@ -1132,8 +1057,7 @@ and for making posts by email"""
     test_secret_key()
     test_service_url_prefix()
     test_staticfiles()
-    test_template_loader()
-    test_template_context_processors()
+    test_template_settings()
     test_tinymce()
     settings_tester = SettingsTester({
         'CACHE_MIDDLEWARE_ANONYMOUS_ONLY': {
@@ -1170,12 +1094,13 @@ and for making posts by email"""
     if 'manage.py test' in ' '.join(sys.argv):
         test_settings_for_test_runner()
 
+
 def run():
     try:
         if django_settings.ASKBOT_SELF_TEST:
             run_startup_tests()
-    except AskbotConfigError, error:
-        print error
+    except AskbotConfigError as error:
+        print(error)
         sys.exit(1)
     # close DB and cache connections to prevent issues in prefork mode
     connection.close()
