@@ -29,7 +29,7 @@ from django.template import Context
 from django.template.loader import get_template
 from django.utils.translation import ugettext as _
 from django.utils.translation import activate as activate_language
-from django.utils import simplejson
+import simplejson
 
 from celery.decorators import task
 from celery.utils.log import get_task_logger
@@ -152,9 +152,9 @@ def delete_update_notifications_task(rev_ids, keep_activity):
 
 @task(ignore_result=True)
 def notify_author_of_published_revision_celery_task(revision_id):
-    #todo: move this to ``askbot.mail`` module
-    #for answerable email only for now, because
-    #we don't yet have the template for the read-only notification
+    # TODO: move this to ``askbot.mail`` module
+    # for answerable email only for now, because
+    # we don't yet have the template for the read-only notification
 
     try:
         revision = PostRevision.objects.get(pk=revision_id)
@@ -164,15 +164,15 @@ def notify_author_of_published_revision_celery_task(revision_id):
 
     activate_language(revision.post.language_code)
 
-    if askbot_settings.REPLY_BY_EMAIL == False:
+    if not askbot_settings.REPLY_BY_EMAIL:
         email = ApprovedPostNotification({
             'post': revision.post,
             'recipient_user': revision.author
         })
-        email.send([revision.author.email,])
+        email.send([revision.author.email])
     else:
-        #generate two reply codes (one for edit and one for addition)
-        #to format an answerable email or not answerable email
+        # generate two reply codes (one for edit and one for addition)
+        # to format an answerable email or not answerable email
         reply_options = {
             'user': revision.author,
             'post': revision.post,
@@ -198,20 +198,14 @@ def notify_author_of_published_revision_celery_task(revision_id):
             'append_content_address': append_content_address,
             'replace_content_address': replace_content_address
         })
-        email.send([revision.author.email,])
+        email.send([revision.author.email])
 
 
 @task(ignore_result=True)
 def record_post_update_celery_task(
-        post_id,
-        newly_mentioned_user_id_list=None,
-        updated_by_id=None,
-        suppress_email=False,
-        timestamp=None,
-        created=False,
-        diff=None,
-    ):
-    #reconstitute objects from the database
+        post_id, newly_mentioned_user_id_list=None, updated_by_id=None,
+        suppress_email=False, timestamp=None, created=False, diff=None):
+    # reconstitute objects from the database
     updated_by = User.objects.get(id=updated_by_id)
     post = Post.objects.get(id=post_id)
     newly_mentioned_users = User.objects.filter(
@@ -219,9 +213,8 @@ def record_post_update_celery_task(
                             )
     try:
         notify_sets = post.get_notify_sets(
-                                mentioned_users=newly_mentioned_users,
-                                exclude_list=[updated_by,]
-                            )
+            mentioned_users=newly_mentioned_users,
+            exclude_list=[updated_by])
 
         activity_type = post.get_updated_activity_type(created)
         post.issue_update_notifications(
@@ -230,27 +223,22 @@ def record_post_update_celery_task(
             activity_type=activity_type,
             suppress_email=suppress_email,
             timestamp=timestamp,
-            diff=diff
-        )
-
+            diff=diff)
     except Exception:
         logger.error(unicode(traceback.format_exc()).encode('utf-8'))
 
+
 @task(ignore_result=True)
 def record_question_visit(
-    language_code=None,
-    question_post_id=None,
-    update_view_count=False,
-    user_id=None
-):
+        language_code=None, question_post_id=None, update_view_count=False,
+        user_id=None):
     """celery task which records question visit by a person
     updates view counter, if necessary,
     and awards the badges associated with the
     question visit
     """
     activate_language(language_code)
-    #1) maybe update the view count
-
+    # 1) maybe update the view count
     try:
         question_post = Post.objects.get(id=question_post_id)
     except Post.DoesNotExist:
@@ -266,9 +254,9 @@ def record_question_visit(
 
     user = User.objects.get(id=user_id)
 
-    #2) question view count per user and clear response displays
+    # 2) question view count per user and clear response displays
     if user.is_authenticated():
-        #get response notifications
+        # get response notifications
         user.visit_question(question_post)
 
     #3) send award badges signal for any badges
@@ -280,10 +268,7 @@ def record_question_visit(
 
 @task()
 def send_instant_notifications_about_activity_in_post(
-                                                activity_id=None,
-                                                post_id=None,
-                                                recipients=None,
-                                            ):
+        activity_id=None, post_id=None, recipients=None):
 
     if recipients is None:
         recipients = set()
@@ -296,7 +281,9 @@ def send_instant_notifications_about_activity_in_post(
 
     acceptable_types = const.RESPONSE_ACTIVITY_TYPES_FOR_INSTANT_NOTIFICATIONS
     try:
-        update_activity = Activity.objects.filter(activity_type__in=acceptable_types).get(id=activity_id)
+        update_activity = Activity.objects\
+            .filter(activity_type__in=acceptable_types)\
+            .get(id=activity_id)
     except Activity.DoesNotExist:
         logger.error("Unable to fetch activity with id %s" % post_id)
         return
@@ -307,7 +294,7 @@ def send_instant_notifications_about_activity_in_post(
         logger.error("Unable to fetch post with id %s" % post_id)
         return
 
-    if post.is_approved() is False:
+    if not post.is_approved():
         return
 
     if logger.getEffectiveLevel() <= logging.DEBUG:
@@ -324,14 +311,14 @@ def send_instant_notifications_about_activity_in_post(
         activate_language(post.language_code)
 
         email = InstantEmailAlert({
-                        'to_user': user,
-                        'from_user': update_activity.user,
-                        'post': post,
-                        'update_activity': update_activity
-                    })
+            'to_user': user,
+            'from_user': update_activity.user,
+            'post': post,
+            'update_activity': update_activity
+        })
         try:
             email.send([user.email])
-        except askbot_exceptions.EmailNotSent, error:
+        except askbot_exceptions.EmailNotSent as error:
             logger.debug(
                 '%s, error=%s, logId=%s' % (user.email, error, log_id)
             )
