@@ -6,13 +6,15 @@ import urllib
 from coffin import template as coffin_template
 from bs4 import BeautifulSoup
 from django.core import exceptions as django_exceptions
+from django.utils.encoding import force_unicode
 from django.utils.translation import ugettext as _
 from django.utils.translation import get_language as django_get_language
 from django.contrib.humanize.templatetags import humanize
 from django.template import defaultfilters
 from django.core.urlresolvers import reverse, resolve
 from django.http import Http404
-from django.utils import simplejson, timezone
+import simplejson
+from django.utils import timezone
 from django.utils.text import Truncator
 from askbot import exceptions as askbot_exceptions
 from askbot.conf import settings as askbot_settings
@@ -397,6 +399,8 @@ def sub_vars(text, user=None):
     sitename_re = re.compile(r'\{\{\s*SITE_NAME\s*\}\}')
     sitelink_re = re.compile(r'\{\{\s*SITE_LINK\s*\}\}')
 
+    text = force_unicode(text)
+
     if user:
         if user.is_anonymous():
             username = _('Visitor')
