@@ -2,21 +2,16 @@
 askbot url configuraion file
 """
 import os.path
-import django
 from django.conf import settings
-
+from django.contrib import admin
 try:
     from django.conf.urls import url, patterns, include
-    from django.conf.urls import handler404
 except ImportError:
     from django.conf.urls.defaults import url, patterns, include
-    from django.conf.urls.defaults import handler404
 
-from django.contrib import admin
 from askbot import views
 from askbot.feed import RssLastestQuestionsFeed, RssIndividualQuestionFeed
 from askbot.sitemap import QuestionsSitemap
-from askbot.skins.utils import update_media_revision
 from askbot.utils.url_utils import service_url
 
 admin.autodiscover()
@@ -28,7 +23,7 @@ else:
 
 feeds = {
     'rss': RssLastestQuestionsFeed,
-    'question':RssIndividualQuestionFeed
+    'question': RssIndividualQuestionFeed
 }
 sitemaps = {
     'questions': QuestionsSitemap
@@ -38,7 +33,8 @@ MAIN_PAGE_BASE_URL = settings.ASKBOT_MAIN_PAGE_BASE_URL
 QUESTION_PAGE_BASE_URL = settings.ASKBOT_QUESTION_PAGE_BASE_URL
 
 APP_PATH = os.path.dirname(__file__)
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     url(r'^$', views.readers.index, name='index'),
     # BEGIN Questions (main page) urls. All this urls work both normally and through ajax
     url(
@@ -76,14 +72,14 @@ urlpatterns = patterns('',
                                             pgettext('urls', 'by-group/')
                                         ),
         views.users.show_users,
-        kwargs = {'by_group': True},
-        name = 'users_by_group'
+        kwargs={'by_group': True},
+        name='users_by_group'
     ),
-    #todo: rename as user_edit, b/c that's how template is named
+    # TODO: rename as user_edit, b/c that's how template is named
     url(
         r'^%s(?P<id>\d+)/%s$' % (pgettext('urls', 'users/'), pgettext('urls', 'edit/')),
         views.users.edit_user,
-        name ='edit_user'
+        name='edit_user'
     ),
     service_url(
         r'^%s(?P<id>\d+)/%s(?P<file_name>.+)/$' % (pgettext('urls', 'users/'), pgettext('urls', 'download-data/')),
@@ -116,8 +112,8 @@ urlpatterns = patterns('',
             pgettext('urls', 'subscriptions/'),
         ),
         views.users.user,
-        kwargs = {'tab_name': 'email_subscriptions'},
-        name = 'user_subscriptions'
+        kwargs={'tab_name': 'email_subscriptions'},
+        name='user_subscriptions'
     ),
     url(
         r'^%s%s$' % (
@@ -125,7 +121,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'unsubscribe/'),
         ),
         views.users.user_unsubscribe,
-        name = 'user_unsubscribe'
+        name='user_unsubscribe'
     ),
     url(
         r'^%s(?P<id>\d+)/(?P<slug>.+)/%s$' % (
@@ -133,7 +129,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'select_languages/'),
         ),
         views.users.user_select_languages,
-        name = 'user_select_languages'
+        name='user_select_languages'
     ),
     url(
         r'^%s(?P<id>\d+)/(?P<slug>.+)/$' % pgettext('urls', 'users/'),
@@ -161,27 +157,27 @@ urlpatterns = patterns('',
         {'sitemaps': sitemaps},
         name='sitemap'
     ),
-    #feeds
+    # feeds
     url(r'^feeds/rss/$', RssLastestQuestionsFeed(), name="latest_questions_feed"),
     url(r'^feeds/question/(?P<pk>\d+)/$', RssIndividualQuestionFeed(), name="individual_question_feed"),
     url(r'^%s$' % pgettext('urls', 'feedback/'), views.meta.feedback, name='feedback'),
     url(
         '^custom\.css$',
         views.meta.config_variable,
-        kwargs = {
+        kwargs={
             'variable_name': 'CUSTOM_CSS',
-            'mimetype': 'text/css'
+            'content_type': 'text/css'
         },
-        name = 'custom_css'
+        name='custom_css'
     ),
     url(
         '^custom\.js$',
         views.meta.config_variable,
-        kwargs = {
+        kwargs={
             'variable_name': 'CUSTOM_JS',
-            'mimetype': 'text/javascript'
+            'content_type': 'text/javascript'
         },
-        name = 'custom_js'
+        name='custom_js'
     ),
     service_url(r'^translate-url/', views.commands.translate_url, name='translate_url'),
     service_url(r'^reorder-badges/', views.commands.reorder_badges, name='reorder_badges'),
@@ -204,7 +200,7 @@ urlpatterns = patterns('',
     url(
         r'^%s(?P<id>\d+)/%s$' % (pgettext('urls', 'answers/'), pgettext('urls', 'revisions/')),
         views.readers.revisions,
-        kwargs = {'post_type': 'answer'},
+        kwargs={'post_type': 'answer'},
         name='answer_revisions'
     ),
     service_url(
@@ -266,12 +262,12 @@ urlpatterns = patterns('',
     service_url(
         r'^save-draft-question/',
         views.commands.save_draft_question,
-        name = 'save_draft_question'
+        name='save_draft_question'
     ),
     service_url(
         r'^save-draft-answer/',
         views.commands.save_draft_answer,
-        name = 'save_draft_answer'
+        name='save_draft_answer'
     ),
     service_url(
         r'^share-question-with-group/',
@@ -308,7 +304,7 @@ urlpatterns = patterns('',
         views.writers.edit_question,
         name='edit_question'
     ),
-    service_url(#this url is both regular and ajax
+    service_url(  # this url is both regular and ajax
         r'^%s(?P<id>\d+)/%s$' % (MAIN_PAGE_BASE_URL, pgettext('urls', 'retag/')),
         views.writers.retag_question,
         name='retag_question'
@@ -333,7 +329,7 @@ urlpatterns = patterns('',
         views.commands.merge_questions,
         name='merge_questions'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^vote$',
         views.commands.vote,
         name='vote'
@@ -341,35 +337,35 @@ urlpatterns = patterns('',
     url(
         r'^%s(?P<id>\d+)/%s$' % (MAIN_PAGE_BASE_URL, pgettext('urls', 'revisions/')),
         views.readers.revisions,
-        kwargs = {'post_type': 'question'},
+        kwargs={'post_type': 'question'},
         name='question_revisions'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^comment/upvote/$',
         views.commands.upvote_comment,
-        name = 'upvote_comment'
+        name='upvote_comment'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^post/delete/$',
         views.commands.delete_post,
-        name = 'delete_post'
+        name='delete_post'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^post_comments/$',
         views.writers.post_comments,
         name='post_comments'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^edit_comment/$',
         views.writers.edit_comment,
         name='edit_comment'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^comment/delete/$',
         views.writers.delete_comment,
         name='delete_comment'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^comment/get-text/$',
         views.readers.get_comment,
         name='get_comment'
@@ -385,13 +381,13 @@ urlpatterns = patterns('',
         kwargs={'destination': 'comment_under_question'},
         name='repost_answer_as_comment_under_question'
     ),
-    service_url(#post only
+    service_url(  # post only
         '^answer/repost-as-comment-under-previous-answer/$',
         views.writers.repost_answer_as_comment,
         kwargs={'destination': 'comment_under_previous_answer'},
         name='repost_answer_as_comment_under_previous_answer'
     ),
-    service_url(#post only
+    service_url(  # post only
         r'^answer/publish/$',
         views.commands.publish_answer,
         name='publish_answer'
@@ -401,7 +397,7 @@ urlpatterns = patterns('',
         views.commands.list_bulk_tag_subscription,
         name='list_bulk_tag_subscription'
     ),
-    service_url(#post only
+    service_url(  # post only
         r'^%s%s%s$' % (
             pgettext('urls', 'tags/'),
             pgettext('urls', 'subscriptions/'),
@@ -431,117 +427,117 @@ urlpatterns = patterns('',
     service_url(
         r'^%s$' % pgettext('urls', 'suggested-tags/'),
         views.meta.list_suggested_tags,
-        name = 'list_suggested_tags'
+        name='list_suggested_tags'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^%s$' % 'moderate-suggested-tag',
         views.commands.moderate_suggested_tag,
-        name = 'moderate_suggested_tag'
+        name='moderate_suggested_tag'
     ),
-    #todo: collapse these three urls and use an extra json data var
-    service_url(#ajax only
+    # TODO: collapse these three urls and use an extra json data var
+    service_url(  # ajax only
         r'^%s%s$' % ('mark-tag/', 'interesting/'),
         views.commands.mark_tag,
-        kwargs={'reason':'good','action':'add'},
+        kwargs={'reason': 'good', 'action': 'add'},
         name='mark_interesting_tag'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^%s%s$' % ('mark-tag/', 'ignored/'),
         views.commands.mark_tag,
-        kwargs={'reason':'bad','action':'add'},
+        kwargs={'reason': 'bad', 'action': 'add'},
         name='mark_ignored_tag'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^%s%s$' % ('mark-tag/', 'subscribed/'),
         views.commands.mark_tag,
-        kwargs={'reason':'subscribed','action':'add'},
+        kwargs={'reason': 'subscribed', 'action': 'add'},
         name='mark_subscribed_tag'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^unmark-tag/',
         views.commands.mark_tag,
-        kwargs={'action':'remove'},
+        kwargs={'action': 'remove'},
         name='unmark_tag'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^clean-tag-name/',
         views.commands.clean_tag_name,
         name='clean_tag_name'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^set-tag-filter-strategy/',
         views.commands.set_tag_filter_strategy,
-        name = 'set_tag_filter_strategy'
+        name='set_tag_filter_strategy'
     ),
     service_url(
         r'^get-tags-by-wildcard/',
         views.commands.get_tags_by_wildcard,
-        name = 'get_tags_by_wildcard'
+        name='get_tags_by_wildcard'
     ),
     service_url(
         r'^get-tag-list/',
         views.commands.get_tag_list,
-        name = 'get_tag_list'
+        name='get_tag_list'
     ),
     service_url(
         r'^load-object-description/',
         views.commands.load_object_description,
-        name = 'load_object_description'
+        name='load_object_description'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^save-object-description/',
         views.commands.save_object_description,
-        name = 'save_object_description'
+        name='save_object_description'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^add-tag-category/',
         views.commands.add_tag_category,
-        name = 'add_tag_category'
+        name='add_tag_category'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^rename-tag/',
         views.commands.rename_tag,
-        name = 'rename_tag'
+        name='rename_tag'
     ),
-    service_url(#
+    service_url(
         r'^delete-tag/',
         views.commands.delete_tag,
-        name = 'delete_tag'
+        name='delete_tag'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^save-group-logo-url/',
         views.commands.save_group_logo_url,
-        name = 'save_group_logo_url'
+        name='save_group_logo_url'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^delete-group-logo/',
         views.commands.delete_group_logo,
-        name = 'delete_group_logo'
+        name='delete_group_logo'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^add-group/',
         views.commands.add_group,
-        name = 'add_group'
+        name='add_group'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^toggle-group-profile-property/',
         views.commands.toggle_group_profile_property,
         name='toggle_group_profile_property'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^set-group-openness/',
         views.commands.set_group_openness,
         name='set_group_openness'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^edit-object-property-text/',
         views.commands.edit_object_property_text,
-        name = 'edit_object_property_text'
+        name='edit_object_property_text'
     ),
     service_url(
         r'^get-groups-list/',
         views.commands.get_groups_list,
-        name = 'get_groups_list'
+        name='get_groups_list'
     ),
     service_url(
         r'^toggle-follow-question/',
@@ -551,53 +547,53 @@ urlpatterns = patterns('',
     service_url(
         r'^subscribe-for-tags/$',
         views.commands.subscribe_for_tags,
-        name = 'subscribe_for_tags'
+        name='subscribe_for_tags'
     ),
     service_url(
         r'get-html-template/',
         views.commands.get_html_template,
         name='get_html_template'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^messages/markread/$',
         views.commands.read_message,
         name='read_message'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^clear-new-notifications/$',
         views.users.clear_new_notifications,
         name='clear_new_notifications'
     ),
-    service_url(#ajax_only
+    service_url(  # ajax_only
         r'^delete-notifications/$',
         views.users.delete_notifications,
         name='delete_notifications'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^save-post-reject-reason/$',
         views.commands.save_post_reject_reason,
         name='save_post_reject_reason'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^delete-post-reject-reason/$',
         views.commands.delete_post_reject_reason,
         name='delete_post_reject_reason'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^edit-group-membership/$',
         views.commands.edit_group_membership,
         name='edit_group_membership'
     ),
-    service_url(#ajax only
+    service_url(  # ajax only
         r'^join-or-leave-group/$',
         views.commands.join_or_leave_group,
-        name = 'join_or_leave_group'
+        name='join_or_leave_group'
     ),
-    #widgets url!
+    # widgets url!
     service_url(
         r'^%s$' % (pgettext('urls', 'widgets/')),
         views.widgets.widgets,
-        name = 'widgets'
+        name='widgets'
     ),
     service_url(
         r'^%s%s(?P<widget_id>\d+)/$' % (
@@ -605,7 +601,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'ask/')
         ),
         views.widgets.ask_widget,
-        name = 'ask_by_widget'
+        name='ask_by_widget'
     ),
     service_url(
         r'^%s%s(?P<widget_id>\d+).js$' % (
@@ -613,7 +609,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'ask/')
         ),
         views.widgets.render_ask_widget_js,
-        name = 'render_ask_widget'
+        name='render_ask_widget'
     ),
     service_url(
         r'^%s%s(?P<widget_id>\d+).css$' % (
@@ -621,7 +617,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'ask/')
         ),
         views.widgets.render_ask_widget_css,
-        name = 'render_ask_widget_css'
+        name='render_ask_widget_css'
     ),
     service_url(
         r'^%s%s%s$' % (
@@ -630,7 +626,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'complete/')
         ),
         views.widgets.ask_widget_complete,
-        name = 'ask_by_widget_complete'
+        name='ask_by_widget_complete'
     ),
     service_url(
         r'^%s(?P<model>\w+)/%s$' % (
@@ -638,7 +634,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'create/')
         ),
         views.widgets.create_widget,
-        name = 'create_widget'
+        name='create_widget'
     ),
     service_url(
         r'^%s(?P<model>\w+)/%s(?P<widget_id>\d+)/$' % (
@@ -646,7 +642,7 @@ urlpatterns = patterns('',
             pgettext('urls', 'edit/')
         ),
         views.widgets.edit_widget,
-        name = 'edit_widget'
+        name='edit_widget'
     ),
     service_url(
         r'^%s(?P<model>\w+)/%s(?P<widget_id>\d+)/$' % (
@@ -654,12 +650,12 @@ urlpatterns = patterns('',
             pgettext('urls', 'delete/')
         ),
         views.widgets.delete_widget,
-        name = 'delete_widget'
+        name='delete_widget'
     ),
     service_url(
         r'^%s(?P<model>\w+)/$' % (pgettext('urls', 'widgets/')),
         views.widgets.list_widgets,
-        name = 'list_widgets'
+        name='list_widgets'
     ),
     service_url(
         r'^widgets/%s(?P<widget_id>\d+)/$' % MAIN_PAGE_BASE_URL,
@@ -681,12 +677,12 @@ urlpatterns = patterns('',
         views.sharing.save_twitter_access_token,
         name='save_twitter_access_token'
     ),
-    service_url(#ajax post only
+    service_url(  # ajax post only
         r'^change-social-sharing-mode/$',
         views.sharing.change_social_sharing_mode,
         name='change_social_sharing_mode'
     ),
-    #upload url is ajax only
+    # upload url is ajax only
     service_url(
         r'^%s$' % pgettext('urls', 'upload/'),
         views.writers.upload,
@@ -695,16 +691,16 @@ urlpatterns = patterns('',
     service_url(
         r'^doc/(?P<path>.*)$',
         'django.views.static.serve',
-        {'document_root': os.path.join(APP_PATH,'doc','build','html').replace('\\','/')},
+        {'document_root': os.path.join(APP_PATH, 'doc', 'build', 'html').replace('\\', '/')},
         name='askbot_docs',
     ),
     service_url(
         r'^jsi18n/$',
         'django.views.i18n.javascript_catalog',
-        {'domain': 'djangojs','packages': ('askbot',)},
-        name = 'askbot_jsi18n'
+        {'domain': 'djangojs', 'packages': ('askbot',)},
+        name='askbot_jsi18n'
     ),
-    service_url(r'^private-messages/', include('group_messaging.urls')),
+    service_url(r'^private-messages/', include('askbot.deps.group_messaging.urls')),
     url(r'^settings/', include('livesettings.urls')),
     url(r'^preview-emails/$', views.emails.list_emails, name='list_emails'),
     url(r'^preview-emails/(?P<slug>.+)/$', views.emails.preview_email, name='preview_email'),
@@ -714,6 +710,7 @@ urlpatterns = patterns('',
     url('^api/v1/users/(?P<user_id>\d+)/$', views.api_v1.user, name='api_v1_user'),
     url('^api/v1/questions/$', views.api_v1.questions, name='api_v1_questions'),
     url('^api/v1/questions/(?P<question_id>\d+)/$', views.api_v1.question, name='api_v1_question'),
+    url('^api/v1/answers/(?P<answer_id>\d+)/$', views.api_v1.answer, name='api_v1_answer'),
 )
 
 if 'askbot.deps.django_authopenid' in settings.INSTALLED_APPS:
@@ -726,9 +723,9 @@ if 'askbot.deps.django_authopenid' in settings.INSTALLED_APPS:
 
 if 'avatar' in settings.INSTALLED_APPS:
     urlpatterns += (
-        #avatar views are added here, because some need
-        #either dynamic extra context or custom redirect
-        #or extra parameter in the urls
+        # avatar views are added here, because some need
+        # either dynamic extra context or custom redirect
+        # or extra parameter in the urls
         service_url(
             '^avatar/upload/(?P<user_id>\d+)/$',
             views.avatar_views.upload,
@@ -749,7 +746,7 @@ if 'avatar' in settings.INSTALLED_APPS:
             views.avatar_views.delete,
             name='askbot_avatar_delete'
         ),
-        service_url(#this url is used without changes as in the avatar app
+        service_url(  # this url is used without changes as in the avatar app
             '^avatar/render-primary/(?P<user>[\w\d\.\-_]+)/(?P<size>[\d]+)/$',
             'avatar.views.render_primary',
             name='avatar_render_primary'
