@@ -9,7 +9,8 @@ from django.core import exceptions as django_exceptions
 from django.core.urlresolvers import reverse
 from django.http import HttpResponse, HttpResponseForbidden, Http404
 from django.http import HttpResponseRedirect
-from django.utils import simplejson, timezone
+import simplejson
+from django.utils import timezone
 from django.utils.translation import ugettext as _
 from django.utils.encoding import smart_str
 from askbot import exceptions as askbot_exceptions
@@ -86,7 +87,7 @@ def ajax_only(view_func):
             data = view_func(request, *args, **kwargs)
             if data is None:
                 data = {}
-        except Exception, e:
+        except Exception as e:
             #todo: also check field called "message"
             if hasattr(e, 'messages'):
                 if len(e.messages) > 1:
@@ -109,7 +110,7 @@ def ajax_only(view_func):
             return HttpResponse(simplejson.dumps(data), content_type='application/json')
 
         if isinstance(data, HttpResponse):#is this used?
-            data.mimetype = 'application/json'
+            data.content_type = 'application/json'
             return data
         else:
             data['success'] = 1
@@ -181,6 +182,7 @@ def profile(log_file):
         return _inner
     return _outer
 
+
 def moderators_only(view_func):
     @functools.wraps(view_func)
     def decorator(request, *args, **kwargs):
