@@ -3,6 +3,7 @@ import datetime
 import os
 import re
 import random
+import simplejson
 import time
 import warnings
 import zlib
@@ -17,7 +18,6 @@ from django.utils import six
 from django.utils.functional import lazy
 from django.utils.safestring import mark_safe
 from django.utils import timezone
-from django.utils import simplejson
 from django import forms
 
 mark_safe_lazy = lazy(mark_safe, six.text_type) #pylint: disable=invalid-name
