@@ -1,5 +1,6 @@
 """reads pluralization formulae from the .po files
 and prints out list of languages for each formula"""
+from __future__ import print_function
 import sys
 import os.path
 import collections
@@ -18,5 +19,5 @@ for filename in sys.argv:
     lang_codes[formula].add(lang.split('/')[-1])
 
 for formula in lang_codes:
-    print lang_codes[formula]
-    print formula
+    print(lang_codes[formula])
+    print(formula)
