@@ -1,6 +1,6 @@
 """Utilities for working with database transactions"""
-from django_transaction_signals import defer
 from django.conf import settings as django_settings
+#from django.core.signals import request_finished
 
 class DummyTransaction(object):
     """Dummy transaction class
@@ -12,21 +12,20 @@ class DummyTransaction(object):
     def commit(cls):
         pass
 
-    @classmethod
-    def commit_manually(cls, func):
-        def decorated(*args, **kwargs):
-            func(*args, **kwargs)
-        return decorated
 
 #a utility instance to use instead of the normal transaction object
 dummy_transaction = DummyTransaction()
 
-def defer_celery_task(task, **kwargs):
+def defer_celery_task(task, **task_kwargs):
     if django_settings.CELERY_ALWAYS_EAGER:
-        return task.apply(**kwargs)
+        task.apply(**task_kwargs)
     else:
         from celery import current_task
         if current_task:
             #TODO: look into task chains in celery
-            return task.apply(**kwargs)
-        return defer(task.apply_async, **kwargs)
+            return task.apply(**task_kwargs)
+        task.apply_async(**task_kwargs)
+
+        #def schedule_task(sender, **task_kwargs):
+        #    task.apply_async(**task_kwargs)
+        #request_finished.connect(schedule_task)
