@@ -22,7 +22,8 @@ from django.shortcuts import get_object_or_404
 from django.shortcuts import render
 from django.template.loader import get_template
 from django.views.decorators import csrf
-from django.utils import simplejson, timezone
+import simplejson
+from django.utils import timezone
 from django.utils import translation
 from django.utils.encoding import force_text
 from django.utils.html import escape
@@ -202,7 +203,7 @@ def vote(request):
 
         if vote_type in const.VOTE_TYPES_INVALIDATE_CACHE:
             post.thread.reset_cached_data()
-    except Exception, e:
+    except Exception as e:
         response_data['message'] = unicode(e)
         response_data['success'] = 0
 
@@ -284,7 +285,7 @@ def get_tags_by_wildcard(request):
     count = matching_tags.count()
     names = matching_tags.values_list('name', flat = True)[:20]
     re_data = simplejson.dumps({'tag_count': count, 'tag_names': list(names)})
-    return HttpResponse(re_data, mimetype = 'application/json')
+    return HttpResponse(re_data, content_type='application/json')
 
 @decorators.get_only
 def get_thread_shared_users(request):
@@ -350,14 +351,14 @@ def get_tag_list(request):
                     )
 
     output = '\n'.join(map(escape, tag_names))
-    return HttpResponse(output, mimetype = 'text/plain')
+    return HttpResponse(output, content_type='text/plain')
 
 @decorators.get_only
 def load_object_description(request):
     """returns text of the object description in text"""
     obj = get_db_object_or_404(request.GET)#askbot forms utility
     text = getattr(obj.description, 'text', '').strip()
-    return HttpResponse(text, mimetype = 'text/plain')
+    return HttpResponse(text, content_type='text/plain')
 
 @csrf.csrf_protect
 @decorators.ajax_only
@@ -472,7 +473,7 @@ def get_groups_list(request):
                         'name', flat = True
                     )
     output = '\n'.join(group_names)
-    return HttpResponse(output, mimetype = 'text/plain')
+    return HttpResponse(output, content_type='text/plain')
 
 @csrf.csrf_protect
 def subscribe_for_tags(request):
@@ -643,7 +644,7 @@ def set_question_title(request):
 
     user = request.user
     user.edit_question(question, title=title)
-    return {'title': title}
+    return {'title': question.thread.get_title()}
 
 
 @decorators.ajax_only
@@ -731,7 +732,7 @@ def api_get_questions(request):
             continue
 
     json_data = simplejson.dumps(thread_list)
-    return HttpResponse(json_data, mimetype = "application/json")
+    return HttpResponse(json_data, content_type="application/json")
 
 
 @csrf.csrf_protect
@@ -753,7 +754,7 @@ def set_tag_filter_strategy(request):
         assert(filter_value in allowed_values_dict)
         request.user.email_tag_filter_strategy = filter_value
     request.user.save()
-    return HttpResponse('', mimetype = "application/json")
+    return HttpResponse('', content_type="application/json")
 
 
 @login_required
@@ -782,7 +783,7 @@ def close(request, id):#close question
                 'form': form,
             }
             return render(request, 'close.html', data)
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         request.user.message_set.create(message = unicode(e))
         return HttpResponseRedirect(question.get_absolute_url())
 
@@ -812,7 +813,7 @@ def reopen(request, id):#re-open question
             }
             return render(request, 'reopen.html', data)
 
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         request.user.message_set.create(message = unicode(e))
         return HttpResponseRedirect(question.get_absolute_url())
 
@@ -1242,7 +1243,7 @@ def get_users_info(request):
         user_info_list = user_info_list.values_list('username')
 
     result_list = ['|'.join(info) for info in user_info_list[:limit]]
-    return HttpResponse('\n'.join(result_list), mimetype = 'text/plain')
+    return HttpResponse('\n'.join(result_list), content_type='text/plain')
 
 @csrf.csrf_protect
 def share_question_with_group(request):
