@@ -19,7 +19,8 @@ from django.http import HttpResponseBadRequest
 from django.core.paginator import Paginator, EmptyPage, InvalidPage
 from django.template.loader import get_template
 from django.template import Context, RequestContext
-from django.utils import simplejson, timezone
+import simplejson
+from django.utils import timezone
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
@@ -226,7 +227,7 @@ def questions(request, **kwargs):
 
         ajax_data.update(extra_context)
 
-        return HttpResponse(simplejson.dumps(ajax_data), mimetype = 'application/json')
+        return HttpResponse(simplejson.dumps(ajax_data), content_type='application/json')
 
     else: # non-AJAX branch
 
@@ -443,7 +444,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
 
     try:
         question_post.assert_is_visible_to(request.user)
-    except exceptions.QuestionHidden, error:
+    except exceptions.QuestionHidden as error:
         request.user.message_set.create(message = unicode(error))
         return HttpResponseRedirect(reverse('index'))
 
@@ -489,11 +490,11 @@ def question(request, id):#refactor - long subroutine. display question body, an
 
         try:
             show_comment.assert_is_visible_to(request.user)
-        except exceptions.AnswerHidden, error:
+        except exceptions.AnswerHidden as error:
             request.user.message_set.create(message = unicode(error))
             #use reverse function here because question is not yet loaded
             return HttpResponseRedirect(reverse('question', kwargs = {'id': id}))
-        except exceptions.QuestionHidden, error:
+        except exceptions.QuestionHidden as error:
             request.user.message_set.create(message = unicode(error))
             return HttpResponseRedirect(reverse('index'))
 
@@ -508,7 +509,7 @@ def question(request, id):#refactor - long subroutine. display question body, an
 
         try:
             show_post.assert_is_visible_to(request.user)
-        except django_exceptions.PermissionDenied, error:
+        except django_exceptions.PermissionDenied as error:
             request.user.message_set.create(message = unicode(error))
             return HttpResponseRedirect(reverse('question', kwargs = {'id': id}))
 
@@ -626,6 +627,11 @@ def question(request, id):#refactor - long subroutine. display question body, an
     else:
         group_read_only = False
 
+    #session variable added so that the session is
+    #not empty and is not autodeleted, otherwise anonymous
+    #answer posting is impossible
+    request.session['askbot_write_intent'] = True
+
     data = {
         'active_tab': 'questions',
         'answer' : answer_form,
