@@ -34,7 +34,8 @@ from django.utils.translation import get_language
 from django.utils.translation import string_concat
 from django.utils.translation import ugettext as _
 from django.utils.translation import ungettext
-from django.utils import simplejson, timezone
+import simplejson
+from django.utils import timezone
 from django.utils.html import strip_tags as strip_all_tags
 from django.views.decorators import csrf
 
@@ -43,6 +44,7 @@ from askbot.utils.html import sanitize_html
 from askbot.utils.functions import encode_jwt
 from askbot.utils.transaction import defer_celery_task
 from askbot.mail import send_mail
+from askbot.utils.translation import get_language
 from askbot.mail.messages import (AccountManagementRequest,
                                   UnsubscribeLink)
 from askbot.utils.file_utils import read_file_chunkwise
@@ -94,7 +96,7 @@ def clear_new_notifications(request):
     activity_types += (
         const.TYPE_ACTIVITY_MENTION,
     )
-    post_data = simplejson.loads(request.raw_post_data)
+    post_data = simplejson.loads(request.body)
     memo_set = models.ActivityAuditStatus.objects.filter(
         id__in=post_data['memo_ids'],
         activity__activity_type__in=activity_types,
@@ -105,7 +107,7 @@ def clear_new_notifications(request):
 
 @decorators.ajax_only
 def delete_notifications(request):
-    post_data = simplejson.loads(request.raw_post_data)
+    post_data = simplejson.loads(request.body)
     memo_set = models.ActivityAuditStatus.objects.filter(
         id__in=post_data['memo_ids'],
         user=request.user
@@ -124,10 +126,17 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
         return HttpResponseRedirect(new_url)
 
     users = models.User.objects.exclude(
-                                    askbot_profile__status='b'
+                                    askbot_profile__status__in=('b', 't')
                                 ).exclude(
                                     is_active=False
                                 ).select_related('askbot_profile')
+
+    if askbot.is_multilingual():
+        users = users.filter(
+                    localized_askbot_profiles__language_code=get_language(),
+                    localized_askbot_profiles__is_claimed=True
+                )
+
     group = None
     group_email_moderation_enabled = False
     user_acceptance_level = 'closed'
@@ -191,7 +200,11 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
             order_by_parameter = 'username'
         else:
             # default
-            order_by_parameter = '-askbot_profile__reputation'
+            if askbot.is_multilingual():
+                order_by_parameter = '-localized_askbot_profiles__reputation'
+            else:
+                order_by_parameter = '-askbot_profile__reputation'
+
 
         objects_list = Paginator(
                             users.order_by(order_by_parameter),
@@ -244,7 +257,7 @@ def show_users(request, by_group=False, group_id=None, group_slug=None):
         'search_query' : search_query,
         'tab_id' : sort_method,
         'user_acceptance_level': user_acceptance_level,
-        'user_count': users.count(),
+        'user_count': objects_list.count,
         'user_groups': user_groups,
         'user_membership_level': user_membership_level,
         'users' : users_page,
@@ -279,6 +292,16 @@ def manage_account(request, subject, context):
                 user_msg = _('Thank you, you will soon hear from the site administrator.')
                 request.user.message_set.create(message=user_msg)
 
+        elif 'anonymize_account' in request.POST:
+            if request.user.can_anonymize_account(subject):
+                subject.anonymize()
+                return HttpResponseRedirect(subject.get_absolute_url())
+            else:
+                msg = _('Sorry, something is not right here...')
+                request.user.message_set.create(message=msg)
+                return HttpResponseRedirect(subject.get_absolute_url())
+
+
         elif 'export_data' in request.POST:
             from askbot.tasks import export_user_data
             if has_todays_backup:
@@ -290,10 +313,10 @@ def manage_account(request, subject, context):
                     exporting = True
 
     #todo: get backup download link -> context
-    context['can_terminate_account'] = request.user.can_terminate_account(subject)
     context['has_todays_backup'] = has_todays_backup
     context['backup_file_names'] = subject.get_backup_file_names()
     context['exporting'] = exporting
+    context['anon_user_name'] = models.get_name_of_anonymous_user()
     return render(request, 'user_profile/user_manage_account.html', context)
 
 @decorators.ajax_only
@@ -334,7 +357,7 @@ def download_user_data(request, id, file_name):
     if not os.path.isfile(os.path.join(directory, file_path)):
         return Http404
 
-    response = StreamingHttpResponse(mimetype='application/force-download')
+    response = StreamingHttpResponse(content_type='application/force-download')
     response['Content-Disposition'] = 'attachment; filename=%s' % file_name
     file_obj = open(os.path.join(directory, file_name))
     response.streaming_content = read_file_chunkwise(file_obj)
@@ -387,7 +410,7 @@ def user_moderate(request, subject, context):
                             raise_on_failure = True
                         )
                     message_sent = True
-                except exceptions.EmailNotSent, e:
+                except exceptions.EmailNotSent as e:
                     email_error_message = unicode(e)
                 send_message_form = forms.SendMessageForm()
         else:
@@ -408,10 +431,10 @@ def user_moderate(request, subject, context):
                     rep_delta = -1 * rep_delta
 
                 moderator.moderate_user_reputation(
-                                    user = subject,
-                                    reputation_change = rep_delta,
-                                    comment = comment,
-                                    timestamp = timezone.now(),
+                                    user=subject,
+                                    reputation_change=rep_delta,
+                                    comment=comment,
+                                    timestamp=timezone.now(),
                                 )
                 #reset form to preclude accidentally repeating submission
                 user_rep_form = forms.ChangeUserReputationForm()
@@ -499,11 +522,11 @@ def edit_user(request, id):
             user.website = sanitize_html(form.cleaned_data['website'])
             user.location = sanitize_html(form.cleaned_data['city'])
             user.date_of_birth = form.cleaned_data.get('birthday', None)
-            user.about = sanitize_html(form.cleaned_data['about'])
             user.country = form.cleaned_data['country']
             user.show_country = form.cleaned_data['show_country']
             user.show_marked_tags = form.cleaned_data['show_marked_tags']
             user.save()
+            user.update_localized_profile(about=sanitize_html(form.cleaned_data['about']))
             # send user updated signal if full fields have been updated
             award_badges_signal.send(None,
                                      event='update_user_profile',
@@ -526,7 +549,10 @@ def edit_user(request, id):
 
 def user_stats(request, user, context):
     question_filter = {}
-    if request.user != user:
+
+    is_author = (request.user == user)
+    is_mod = request.user.is_authenticated() and request.user.is_administrator_or_moderator()
+    if not (is_mod or is_author):
         question_filter['is_anonymous'] = False
 
     if askbot_settings.CONTENT_MODERATION_MODE == 'premoderation':
@@ -614,7 +640,6 @@ def user_stats(request, user, context):
 #        tag_ids.add(t['thread__tags'])
 #        if t['thread__tags'] == 11:
 #            print t['thread'], t['id']
-#    import ipdb; ipdb.set_trace()
 
     #
     # Badges/Awards (TODO: refactor into Managers/QuerySets when a pattern emerges; Simplify when we get rid of Question&Answer models)
@@ -675,7 +700,7 @@ def user_stats(request, user, context):
     show_moderation_warning = (request.user.is_authenticated()
                                 and request.user.pk == user.pk
                                 and (user.is_watched() or user.is_blocked())
-                                and (user.about or user.website)
+                                and (user.get_localized_profile().about or user.website)
                               )
     show_profile_info = ((not (user.is_watched() or user.is_blocked()))
                           or (request.user.is_authenticated()
@@ -741,7 +766,7 @@ def get_user_description(request):
 
     user_id = form.cleaned_data['user_id']
     user = models.User.objects.get(pk=user_id)
-    return {'description': user.about}
+    return {'description': user.get_localized_profile().about}
 
 
 @csrf.csrf_protect
@@ -768,8 +793,7 @@ def set_user_description(request):
         raise django_exceptions.PermissionDenied(message)
 
     if user_id == request.user.pk or request.user.is_admin_or_mod():
-        user.askbot_profile.about = description
-        user.askbot_profile.save()
+        user.update_localized_profile(about=description)
         return {'description_html': convert_text(description)}
 
     raise django_exceptions.PermissionDenied
@@ -952,7 +976,7 @@ def user_responses(request, user, context):
             elif not(request.user.is_moderator() or request.user.is_administrator()):
                 raise Http404
 
-        from group_messaging.views import SendersList, ThreadsList
+        from askbot.deps.group_messaging.views import SendersList, ThreadsList
         context.update(SendersList().get_context(request))
         context.update(ThreadsList().get_context(request, user))
         data = {
@@ -965,8 +989,8 @@ def user_responses(request, user, context):
         }
         context.update(data)
         if 'thread_id' in request.GET:
-            from group_messaging.models import Message
-            from group_messaging.views import ThreadDetails
+            from askbot.deps.group_messaging.models import Message
+            from askbot.deps.group_messaging.views import ThreadDetails
             try:
                 thread_id = request.GET['thread_id']
                 context.update(ThreadDetails().get_context(request, thread_id))
@@ -993,7 +1017,7 @@ def user_responses(request, user, context):
                     'activity__content_type',
                     'activity__question__thread',
                     'activity__user',
-                    'activity__user__gravatar',
+                    'activity__user__askbot_profile__gravatar',
                 ).order_by(
                     '-activity__active_at'
                 )[:const.USER_VIEW_DATA_SIZE]
@@ -1106,11 +1130,22 @@ def user_votes(request, user, context):
 
 
 def user_reputation(request, user, context):
-    reputes = models.Repute.objects.filter(user=user).select_related('question', 'question__thread', 'user').order_by('-reputed_at')
+    reputes = models.Repute.objects.filter(
+                                        user=user,
+                                        language_code=get_language()
+                                    ).order_by(
+                                        '-reputed_at'
+                                    ).select_related(
+                                        'question',
+                                        'question__thread',
+                                        'user'
+                                    )
+                                    
 
     def format_graph_data(raw_data, user):
         # prepare data for the graph - last values go in first
-        rep_list = ['[%s,%s]' % (calendar.timegm(datetime.datetime.now().timetuple()) * 1000, user.reputation)]
+        final_rep = user.get_localized_profile().reputation + const.MIN_REPUTATION
+        rep_list = ['[%s,%s]' % (calendar.timegm(datetime.datetime.now().timetuple()) * 1000, final_rep)]
         for rep in raw_data:
             rep_list.append('[%s,%s]' % (calendar.timegm(rep.reputed_at.timetuple()) * 1000, rep.reputation))
 
@@ -1127,7 +1162,9 @@ def user_reputation(request, user, context):
         raw_graph_data = reputes
     else:
         #extract only a sampling of data to limit the number of data points
-        rep_qs = models.Repute.objects.filter(user=user).order_by('-id')
+        rep_qs = models.Repute.objects.filter(user=user,
+                                              language_code=get_language()
+                                             ).order_by('-reputed_at')
         #extract 300 points
         raw_graph_data = list()
         step = rep_length / float(sample_size)
@@ -1195,8 +1232,9 @@ def user_set_primary_language(request):
 
     form = forms.LanguageForm(request.POST)
     if form.is_valid():
-        request.user.set_primary_language(form.cleaned_data['language'])
-        request.user.save()
+        profile = request.user.askbot_profile
+        profile.primary_language = form.cleaned_data['language']
+        profile.save()
 
 
 @csrf.csrf_protect
@@ -1216,8 +1254,10 @@ def user_select_languages(request, id=None, slug=None):
         form = forms.LanguagePrefsForm(request.POST)
         if form.is_valid():
             user.set_languages(form.cleaned_data['languages'])
-            user.set_primary_language(form.cleaned_data['primary_language'])
             user.save()
+            profile = user.askbot_profile
+            profile.primary_language = form.cleaned_data['primary_language']
+            profile.save()
 
             redirect_url = reverse(
                 'user_select_languages',
@@ -1302,7 +1342,7 @@ def user_email_subscriptions(request, user, context):
 
     if request.method == 'POST':
         email_feeds_form = forms.EditUserEmailFeedsForm(request.POST)
-        tag_filter_form = forms.TagFilterSelectionForm(request.POST, instance=user)
+        tag_filter_form = forms.TagFilterSelectionForm(request.POST, instance=user.askbot_profile)
         if email_feeds_form.is_valid() and tag_filter_form.is_valid():
 
             tag_filter_saved = tag_filter_form.save()
@@ -1328,7 +1368,7 @@ def user_email_subscriptions(request, user, context):
         #initialize the form
         email_feeds_form = forms.EditUserEmailFeedsForm()
         email_feeds_form.set_initial_values(user)
-        tag_filter_form = forms.TagFilterSelectionForm(instance=user)
+        tag_filter_form = forms.TagFilterSelectionForm(instance=user.askbot_profile)
 
     data = {
         'active_tab': 'users',
@@ -1397,6 +1437,15 @@ def user(request, id, slug=None, tab_name=None):
     """
     profile_owner = get_object_or_404(models.User, id = id)
 
+    if profile_owner.is_terminated():
+        if request.user.pk == profile_owner.pk:
+            return render(request, 'user_profile/account_terminated.html')
+        if request.user.is_authenticated():
+            if not request.user.is_administrator_or_moderator():
+                raise Http404
+        else:
+            raise Http404
+
     if profile_owner.is_blocked():
         if request.user.is_anonymous() \
             or not request.user.is_administrator_or_moderator():
