@@ -20,7 +20,8 @@ from django.http import HttpResponseBadRequest
 from django.http import HttpResponseForbidden
 from django.http import HttpResponseRedirect
 from django.http import Http404
-from django.utils import simplejson, timezone
+import simplejson
+from django.utils import timezone
 from django.utils.html import strip_tags, escape
 from django.utils.translation import get_language
 from django.utils.translation import ugettext as _
@@ -96,9 +97,9 @@ def upload(request):#ajax upload file to a question or answer
                     {'file_size': settings.ASKBOT_MAX_UPLOAD_FILE_SIZE}
             raise exceptions.PermissionDenied(msg)
 
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         error = unicode(e)
-    except Exception, e:
+    except Exception as e:
         logging.critical(unicode(e))
         error = _('Error uploading file. Please contact the site administrator. Thank you.')
 
@@ -113,7 +114,7 @@ def upload(request):#ajax upload file to a question or answer
     #    'error': error,
     #    'file_url': file_url
     #})
-    #return HttpResponse(data, mimetype = 'application/json')
+    #return HttpResponse(data, content_type='application/json')
     xml_template = "<result><msg><![CDATA[%s]]></msg><error><![CDATA[%s]]></error><file_url>%s</file_url><orig_file_name><![CDATA[%s]]></orig_file_name></result>"
     xml = xml_template % (result, error, file_url, orig_file_name)
 
@@ -260,13 +261,15 @@ def ask(request):#view used to ask a new question
                         form_data=form.cleaned_data
                     )
                     return HttpResponseRedirect(question.get_absolute_url())
-                except exceptions.PermissionDenied, e:
+                except exceptions.PermissionDenied as e:
                     request.user.message_set.create(message = unicode(e))
                     return HttpResponseRedirect(reverse('index'))
 
             else:
-                request.session.flush()
                 session_key=request.session.session_key
+                if session_key is None:
+                    return HttpResponseForbidden()
+
                 models.AnonymousQuestion.objects.create(
                     session_key=session_key,
                     title=title,
@@ -281,6 +284,9 @@ def ask(request):#view used to ask a new question
 
     if request.method == 'GET':
         form = forms.AskForm(user=request.user)
+        #session key used only to enable anonymous asking
+        #as django will autodelete empty sessions
+        request.session['askbot_write_intent'] = True
 
     draft_title = ''
     draft_text = ''
@@ -377,7 +383,7 @@ def retag_question(request, id):
             'form' : form,
         }
         return render(request, 'question_retag.html', data)
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         if request.is_ajax():
             response_data = {
                 'message': unicode(e),
@@ -507,7 +513,7 @@ def edit_question(request, id):
         data.update(context.get_for_tag_editor())
         return render(request, 'question_edit.html', data)
 
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         request.user.message_set.create(message = unicode(e))
         return HttpResponseRedirect(question.get_absolute_url())
 
@@ -611,7 +617,7 @@ def edit_answer(request, id):
 
         return render(request, 'answer_edit.html', data)
 
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         request.user.message_set.create(message = unicode(e))
         return HttpResponseRedirect(answer.get_absolute_url())
 
@@ -630,7 +636,11 @@ def answer(request, id, form_class=forms.AnswerForm):#process a new answer
     if askbot_settings.READ_ONLY_MODE_ENABLED:
         return HttpResponseRedirect(question.get_absolute_url())
 
-    if request.method == "POST":
+    if request.method == 'GET':
+        #session key used only to enable anonymous asking
+        #as django will autodelete empty sessions
+        request.session['askbot_write_intent'] = True
+    elif request.method == 'POST':
 
         #this check prevents backward compatilibility
         if form_class == forms.AnswerForm:
@@ -669,14 +679,16 @@ def answer(request, id, form_class=forms.AnswerForm):#process a new answer
                     )
 
                     return HttpResponseRedirect(answer.get_absolute_url())
-                except askbot_exceptions.AnswerAlreadyGiven, e:
+                except askbot_exceptions.AnswerAlreadyGiven as e:
                     request.user.message_set.create(message = unicode(e))
                     answer = question.thread.get_answers_by_user(user)[0]
                     return HttpResponseRedirect(answer.get_absolute_url())
-                except exceptions.PermissionDenied, e:
+                except exceptions.PermissionDenied as e:
                     request.user.message_set.create(message = unicode(e))
             else:
-                request.session.flush()
+                if request.session.session_key is None:
+                    return HttpResponseForbidden()
+
                 models.AnonymousAnswer.objects.create(
                     question=question,
                     wiki=form.cleaned_data['wiki'],
@@ -766,7 +778,7 @@ def post_comments(request):#generic ajax handler to load comments to an object
     if form.is_valid() == False:
         return HttpResponseBadRequest(
             _('This content is forbidden'),
-            mimetype='application/json'
+            content_type='application/json'
         )
 
     post_id = form.cleaned_data['post_id']
@@ -775,7 +787,7 @@ def post_comments(request):#generic ajax handler to load comments to an object
         post = models.Post.objects.get(id=post_id)
     except models.Post.DoesNotExist:
         return HttpResponseBadRequest(
-            _('Post not found'), mimetype='application/json'
+            _('Post not found'), content_type='application/json'
         )
 
     if request.method == "GET":
@@ -808,7 +820,7 @@ def post_comments(request):#generic ajax handler to load comments to an object
                 form_data=form.cleaned_data
             )
             response = __generate_comments_json(post, user, avatar_size)
-        except exceptions.PermissionDenied, e:
+        except exceptions.PermissionDenied as e:
             response = HttpResponseForbidden(unicode(e), content_type="application/json")
 
     return response
@@ -911,10 +923,10 @@ def delete_comment(request):
         raise exceptions.PermissionDenied(
                     _('sorry, we seem to have some technical difficulties')
                 )
-    except exceptions.PermissionDenied, e:
+    except exceptions.PermissionDenied as e:
         return HttpResponseForbidden(
                     unicode(e),
-                    mimetype = 'application/json'
+                    content_type='application/json'
                 )
 
 @login_required
